% Auto-generated chapter 23 for abudawud
% Hadiths in this chapter: 90

\hadithdefcmd{abudawud}{3326}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ قَيْسِ بْنِ أَبِي غَرَزَةَ، قَالَ كُنَّا فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم نُسَمَّى السَّمَاسِرَةَ فَمَرَّ بِنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَسَمَّانَا بِاسْمٍ هُوَ أَحْسَنُ مِنْهُ فَقَالَ ‏ "‏ يَا مَعْشَرَ التُّجَّارِ إِنَّ الْبَيْعَ يَحْضُرُهُ اللَّغْوُ وَالْحَلِفُ فَشُوبُوهُ بِالصَّدَقَةِ ‏"‏ ‏.‏\hadithno{3326}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Qays ibn AbuGharazah: In the time of the Messenger of Allah (ﷺ) we used to be called brokers, but the Prophet (ﷺ) came upon us one day, and called us by a better name than that, saying: O company of merchants, unprofitable speech and swearing takes place in business dealings, so mix it with sadaqah (alms)}}
\hadithdefcmd{abudawud}{3327}{حَدَّثَنَا الْحُسَيْنُ بْنُ عِيسَى الْبُسْطَامِيُّ، وَحَامِدُ بْنُ يَحْيَى، وَعَبْدُ اللَّهِ بْنُ مُحَمَّدٍ الزُّهْرِيُّ، قَالُوا حَدَّثَنَا سُفْيَانُ، عَنْ جَامِعِ بْنِ أَبِي رَاشِدٍ، وَعَبْدِ الْمَلِكِ بْنِ أَعْيَنَ، وَعَاصِمٍ، عَنْ أَبِي وَائِلٍ، عَنْ قَيْسِ بْنِ أَبِي غَرَزَةَ، بِمَعْنَاهُ قَالَ ‏"‏ يَحْضُرُهُ الْكَذِبُ وَالْحَلِفُ ‏"‏ ‏.‏ وَقَالَ عَبْدُ اللَّهِ الزُّهْرِيُّ ‏"‏ اللَّغْوُ وَالْكَذِبُ ‏"‏ ‏.‏\hadithno{3327}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by Qais b. Abi Gharazah through a different chain of narrators to the same effect. This version has:"Lying and swearing have a place on i." 'Abd Allah al-Zuhri said: "Unprofitable speech and lying}}
\hadithdefcmd{abudawud}{3328}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ مُحَمَّدٍ - عَنْ عَمْرٍو، - يَعْنِي ابْنَ أَبِي عَمْرٍو - عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَجُلاً، لَزِمَ غَرِيمًا لَهُ بِعَشْرَةِ دَنَانِيرَ فَقَالَ وَاللَّهِ لاَ أُفَارِقُكَ حَتَّى تَقْضِيَنِي أَوْ تَأْتِيَنِي بِحَمِيلٍ فَتَحَمَّلَ بِهَا النَّبِيُّ صلى الله عليه وسلم فَأَتَاهُ بِقَدْرِ مَا وَعَدَهُ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مِنْ أَيْنَ أَصَبْتَ هَذَا الذَّهَبَ ‏"‏ ‏.‏ قَالَ مِنْ مَعْدِنٍ ‏.‏ قَالَ ‏"‏ لاَ حَاجَةَ لَنَا فِيهَا وَلَيْسَ فِيهَا خَيْرٌ ‏"‏ ‏.‏ فَقَضَاهَا عَنْهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{3328}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: A man seized his debtor who owed ten dinars to him. He said to him: I swear by Allah, I shall not leave you until you pay off (my debt) to me or bring a surety. The Prophet (ﷺ) stood as a surety for him. He then brought as much (money) as he promised. The Prophet (ﷺ) asked: From where did you acquire this gold? He replied: From a mine. He said: We have no need of it; there is no good in it. Then the Messenger of Allah (ﷺ) paid (the debt) on his behalf}}
\hadithdefcmd{abudawud}{3329}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، قَالَ حَدَّثَنَا أَبُو شِهَابٍ، حَدَّثَنَا ابْنُ عَوْنٍ، عَنِ الشَّعْبِيِّ، قَالَ سَمِعْتُ النُّعْمَانَ بْنَ بَشِيرٍ، - وَلاَ أَسْمَعُ أَحَدًا بَعْدَهُ يَقُولُ - سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ إِنَّ الْحَلاَلَ بَيِّنٌ وَإِنَّ الْحَرَامَ بَيِّنٌ وَبَيْنَهُمَا أُمُورٌ مُشْتَبِهَاتٌ ‏"‏ ‏.‏ وَأَحْيَانًا يَقُولُ ‏"‏ مُشْتَبِهَةٌ ‏"‏ ‏.‏ ‏"‏ وَسَأَضْرِبُ لَكُمْ فِي ذَلِكَ مَثَلاً إِنَّ اللَّهَ حَمَى حِمًى وَإِنَّ حِمَى اللَّهِ مَا حَرَّمَ وَإِنَّهُ مَنْ يَرْعَ حَوْلَ الْحِمَى يُوشِكْ أَنْ يُخَالِطَهُ وَإِنَّهُ مَنْ يُخَالِطِ الرِّيبَةَ يُوشِكْ أَنْ يَجْسُرَ ‏"‏ ‏.‏\hadithno{3329}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2051) Sahih Muslim (1599)}\hadithtrans{Narrated Al-Nu'man b. Bashir:I heard the Messenger of Allah (ﷺ) say: What is lawful is clear and what is unlawful is clear, but between them are certain doubtful things. I give you an example for this. Allah has a preserve, and Allah's preserve is the things He has declared unlawful. He who pastures (his animals) round the preserve will soon fall into it. He who falls into doubtful things will soon be courageous}}
\hadithdefcmd{abudawud}{3330}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى الرَّازِيُّ، أَخْبَرَنَا عِيسَى، حَدَّثَنَا زَكَرِيَّا، عَنْ عَامِرٍ الشَّعْبِيِّ، قَالَ سَمِعْتُ النُّعْمَانَ بْنَ بَشِيرٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ بِهَذَا الْحَدِيثِ قَالَ ‏ "‏ وَبَيْنَهُمَا مُشَبَّهَاتٌ لا يَعْلَمُهَا كَثِيرٌ مِنَ النَّاسِ فَمَنِ اتَّقَى الشُّبُهَاتِ اسْتَبْرَأَ عِرْضَهُ وَدِينَهُ وَمَنْ وَقَعَ فِي الشُّبُهَاتِ وَقَعَ فِي الْحَرَامِ ‏"‏ ‏.‏\hadithno{3330}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (52) Sahih Muslim (1599)}\hadithtrans{Narrated Al-Nu'man b. Bashir:I heard Messenger of Allah (ﷺ) say: But between them are certain doubtful things which many people do not recognize. He who guards against doubtful things keeps his religion and his honor blameless, but he who falls into doubtful things falls into what is unlawful}}
\hadithdefcmd{abudawud}{3331}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا عَبَّادُ بْنُ رَاشِدٍ، قَالَ سَمِعْتُ سَعِيدَ بْنَ أَبِي خَيْرَةَ، يَقُولُ حَدَّثَنَا الْحَسَنُ، مُنْذُ أَرْبَعِينَ سَنَةً عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ح وَحَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ أَخْبَرَنَا خَالِدٌ عَنْ دَاوُدَ - يَعْنِي ابْنَ أَبِي هِنْدٍ - وَهَذَا لَفْظُهُ عَنْ سَعِيدِ بْنِ أَبِي خَيْرَةَ عَنِ الْحَسَنِ عَنْ أَبِي هُرَيْرَةَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لَيَأْتِيَنَّ عَلَى النَّاسِ زَمَانٌ لاَ يَبْقَى أَحَدٌ إِلاَّ أَكَلَ الرِّبَا فَإِنْ لَمْ يَأْكُلْهُ أَصَابَهُ مِنْ بُخَارِهِ ‏"‏ ‏.‏ قَالَ ابْنُ عِيسَى ‏"‏ أَصَابَهُ مِنْ غُبَارِهِ ‏"‏ ‏.‏\hadithno{3331}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: A time is certainly coming to mankind when only the receiver of usury will remain, and if he does not receive it, some of its vapour will reach him. Ibn Isa said: Some of its dust will reach him}}
\hadithdefcmd{abudawud}{3332}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، أَخْبَرَنَا ابْنُ إِدْرِيسَ، أَخْبَرَنَا عَاصِمُ بْنُ كُلَيْبٍ، عَنْ أَبِيهِ، عَنْ رَجُلٍ، مِنَ الأَنْصَارِ قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي جَنَازَةٍ فَرَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهُوَ عَلَى الْقَبْرِ يُوصِي الْحَافِرَ ‏"‏ أَوْسِعْ مِنْ قِبَلِ رِجْلَيْهِ أَوْسِعْ مِنْ قِبَلِ رَأْسِهِ ‏"‏ ‏.‏ فَلَمَّا رَجَعَ اسْتَقْبَلَهُ دَاعِيَ امْرَأَةٍ فَجَاءَ وَجِيءَ بِالطَّعَامِ فَوَضَعَ يَدَهُ ثُمَّ وَضَعَ الْقَوْمُ فَأَكَلُوا فَنَظَرَ آبَاؤُنَا رَسُولَ اللَّهِ صلى الله عليه وسلم يَلُوكُ لُقْمَةً فِي فَمِهِ ثُمَّ قَالَ ‏"‏ أَجِدُ لَحْمَ شَاةٍ أُخِذَتْ بِغَيْرِ إِذْنِ أَهْلِهَا ‏"‏ ‏.‏ فَأَرْسَلَتِ الْمَرْأَةُ قَالَتْ يَا رَسُولَ اللَّهِ إِنِّي أَرْسَلْتُ إِلَى الْبَقِيعِ يَشْتَرِي لِي شَاةً فَلَمْ أَجِدْ فَأَرْسَلْتُ إِلَى جَارٍ لِي قَدِ اشْتَرَى شَاةً أَنْ أَرْسِلْ إِلَىَّ بِهَا بِثَمَنِهَا فَلَمْ يُوجَدْ فَأَرْسَلْتُ إِلَى امْرَأَتِهِ فَأَرْسَلَتْ إِلَىَّ بِهَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَطْعِمِيهِ الأَسَارَى ‏"‏ ‏.‏\hadithno{3332}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Asim ibn Kulayb quoted his father's authority for the following statement by one of the Ansar:We went out with the Messenger of Allah (ﷺ) to a funeral, and I saw the Messenger of Allah (ﷺ) at the grave giving this instruction to the grave-digger: Make it wide on the side of his feet, and make it wide on the side of his head. When he came back, he was received by a man who conveyed an invitation from a woman. So he came (to her), to it food was brought, and he put his hand (i.e. took a morsel in his hand); the people did the same and they ate. Our fathers noticed that the Messenger of Allah (ﷺ) was moving a morsel around his mouth. He then said: I find the flesh of a sheep which has been taken without its owner's permission. The woman sent a message to say: Messenger of Allah, I sent (someone) to an-Naqi' to have a sheep bought for me, but there was none; so I sent (a message) to my neighbour who had bought a sheep, asking him to send it to me for the price (he had paid), but he could not be found. I, therefore, sent (a message) to his wife and she sent it to me. The Messenger of Allah (ﷺ) said: Give this food to the prisoners}}
\hadithdefcmd{abudawud}{3333}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا سِمَاكٌ، حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، عَنْ أَبِيهِ، قَالَ لَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم آكِلَ الرِّبَا وَمُوكِلَهُ وَشَاهِدَهُ وَكَاتِبَهُ ‏.‏\hadithno{3333}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Mas'ud: The Messenger of Allah (ﷺ) cursed the one who accepted usury, the one who paid it, the witness to it, and the one who recorded it}}
\hadithdefcmd{abudawud}{3334}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، حَدَّثَنَا شَبِيبُ بْنُ غَرْقَدَةَ، عَنْ سُلَيْمَانَ بْنِ عَمْرٍو، عَنْ أَبِيهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ يَقُولُ ‏"‏ أَلاَ إِنَّ كُلَّ رِبًا مِنْ رِبَا الْجَاهِلِيَّةِ مَوْضُوعٌ لَكُمْ رُءُوسُ أَمْوَالِكُمْ لاَ تَظْلِمُونَ وَلاَ تُظْلَمُونَ ‏.‏ أَلاَ وَإِنَّ كُلَّ دَمٍ مِنْ دَمِ الْجَاهِلِيَّةِ مَوْضُوعٌ وَأَوَّلُ دَمٍ أَضَعُ مِنْهَا دَمُ الْحَارِثِ بْنِ عَبْدِ الْمُطَّلِبِ ‏"‏ ‏.‏ كَانَ مُسْتَرْضَعًا فِي بَنِي لَيْثٍ فَقَتَلَتْهُ هُذَيْلٌ ‏.‏ قَالَ ‏"‏ اللَّهُمَّ هَلْ بَلَّغْتُ ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ ثَلاَثَ مَرَّاتٍ ‏.‏ قَالَ ‏"‏ اللَّهُمَّ اشْهَدْ ‏"‏ ‏.‏ ثَلاَثَ مَرَّاتٍ ‏.‏\hadithno{3334}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Sulaiman b. 'Amr: On the authority of his father: I heard the Messenger of Allah (ﷺ) say in the Farewell Pilgrimage: "Lo, all claims to usury of the pre-Islamic period have been abolished. You shall have your capital sums, deal not unjustly and you shall not be dealt with unjustly. Lo, all claims for blood-vengeance belonging to the pre-Islamic period have been abolished. The first of those murdered among us whose blood-vengeance I remit is al-Harith ibn AbdulMuttalib, who suckled among Banu Layth and killed by Hudhayl." He then said: O Allah, have I conveyed the message? They said: Yes, saying it three times. He then said: O Allah, be witness, saying it three times}}
\hadithdefcmd{abudawud}{3335}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، حَدَّثَنَا ابْنُ وَهْبٍ، ح وَحَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَنْبَسَةُ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، قَالَ قَالَ ابْنُ الْمُسَيَّبِ إِنَّ أَبَا هُرَيْرَةَ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ الْحَلِفُ مَنْفَقَةٌ لِلسِّلْعَةِ مَمْحَقَةٌ لِلْبَرَكَةِ ‏"‏ ‏.‏ قَالَ ابْنُ السَّرْحِ ‏"‏ لِلْكَسْبِ ‏"‏ ‏.‏ وَقَالَ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{3335}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2087) Sahih Muslim (1606)}\hadithtrans{Narrated Abu Hurairah:I heard Messenger of Allah (ﷺ) say: Swearing produces a ready sale for a commodity but blots out the blessing. The narrator Ibn al-Sarh said: "for earning". He also narrated this tradition from Sa'id b. al-Musayyab on the authority of Abu Hurairah from the Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{3336}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا سُفْيَانُ، عَنْ سِمَاكِ بْنِ حَرْبٍ، حَدَّثَنِي سُوَيْدُ بْنُ قَيْسٍ، قَالَ جَلَبْتُ أَنَا وَمَخْرَمَةُ الْعَبْدِيُّ، بَزًّا مِنْ هَجَرَ فَأَتَيْنَا بِهِ مَكَّةَ فَجَاءَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَمْشِي فَسَاوَمَنَا بِسَرَاوِيلَ فَبِعْنَاهُ وَثَمَّ رَجُلٌ يَزِنُ بِالأَجْرِ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ زِنْ وَأَرْجِحْ ‏"‏ ‏.‏\hadithno{3336}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Suwayd ibn Qays: I and Makhrafah al-Abdi imported some garments from Hajar, and brought them to Mecca. The Messenger of Allah (ﷺ) came to us walking, and after he had bargained with us for some trousers, we sold them to him. There was a man who was weighing for payment. The Messenger of Allah (ﷺ) said to him: Weigh out and give overweight}}
\hadithdefcmd{abudawud}{3337}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، وَمُسْلِمُ بْنُ إِبْرَاهِيمَ، - الْمَعْنَى قَرِيبٌ - قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ أَبِي صَفْوَانَ بْنِ عُمَيْرَةَ، قَالَ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم بِمَكَّةَ قَبْلَ أَنْ يُهَاجِرَ بِهَذَا الْحَدِيثِ وَلَمْ يَذْكُرْ يَزِنُ بِالأَجْرِ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ قَيْسٌ كَمَا قَالَ سُفْيَانُ وَالْقَوْلُ قَوْلُ سُفْيَانَ ‏.‏\hadithno{3337}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{The tradition mentioned above (No. 3330) has also been transmitted by AbuSafwan ibn Umayrah through a different chain of narrators. This version has:Abu Safwan said: I came to the Messenger of Allah (ﷺ) at Mecca before his immigration. He then narrated the rest of the tradition, but he did not mention the words "who was weighing for payment". Abu Dawud sad: Qais also transmitted it as Sufyan said: The version of Sufyan is authoritative}}
\hadithdefcmd{abudawud}{3338}{حَدَّثَنَا ابْنُ أَبِي رِزْمَةَ، سَمِعْتُ أَبِي يَقُولُ، قَالَ رَجُلٌ لِشُعْبَةَ خَالَفَكَ سُفْيَانُ ‏.‏ قَالَ دَمَغْتَنِي ‏.‏ وَبَلَغَنِي عَنْ يَحْيَى بْنِ مَعِينٍ قَالَ كُلُّ مَنْ خَالَفَ سُفْيَانَ فَالْقَوْلُ قَوْلُ سُفْيَانَ ‏.‏\hadithno{3338}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Ibn Abi Rizmah:I heard my father say: A man said to Shu'bah: Sufyan opposed you (i.e. narrated a tradition which differs from your version). He replied: You racked my mind. I have been told that Yahya b. Ma'in said: If anyone opposes Sufyan, the version of Sufyan will be acceptable}}
\hadithdefcmd{abudawud}{3339}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا وَكِيعٌ، عَنْ شُعْبَةَ، قَالَ كَانَ سُفْيَانُ أَحْفَظَ مِنِّي ‏.‏\hadithno{3339}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Shu'bah said:The memory of Sufyan was stronger than mine}}
\hadithdefcmd{abudawud}{3340}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ دُكَيْنٍ، حَدَّثَنَا سُفْيَانُ، عَنْ حَنْظَلَةَ، عَنْ طَاوُسٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الْوَزْنُ وَزْنُ أَهْلِ مَكَّةَ وَالْمِكْيَالُ مِكْيَالُ أَهْلِ الْمَدِينَةِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَكَذَا رَوَاهُ الْفِرْيَابِيُّ وَأَبُو أَحْمَدَ عَنْ سُفْيَانَ وَافَقَهُمَا فِي الْمَتْنِ وَقَالَ أَبُو أَحْمَدَ عَنِ ابْنِ عَبَّاسٍ مَكَانَ ابْنِ عُمَرَ وَرَوَاهُ الْوَلِيدُ بْنُ مُسْلِمٍ عَنْ حَنْظَلَةَ قَالَ ‏"‏ وَزْنُ الْمَدِينَةِ وَمِكْيَالُ مَكَّةَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَاخْتُلِفَ فِي الْمَتْنِ فِي حَدِيثِ مَالِكِ بْنِ دِينَارٍ عَنْ عَطَاءٍ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي هَذَا ‏.‏\hadithno{3340}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Umar: The Prophet (ﷺ) said: (The standard) weight is the weight of the people of Mecca, and the (standard) measure is the measure of the people of Medina. Abu Dawud said: Al-Firyabi and Abu Ahmad have also transmitted from Sufyan in a similar way, and he (Ibn Dukain) agreed with them on the text. The version of Abu Ahmad has: "from Ibn 'Abbas" instead of Ibn 'Umar. It has also been transmitted by al-Walid b. Muslim from Hanzalah. This version has: "the weight of Medina and the measure of Mecca." Abu Dawud said: There is a variation in the text of the version of this tradition narrated by Malik b. Dinar from 'Ata' from the Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{3341}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سَعِيدِ بْنِ مَسْرُوقٍ، عَنِ الشَّعْبِيِّ، عَنْ سَمْعَانَ، عَنْ سَمُرَةَ، قَالَ خَطَبَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ هَا هُنَا أَحَدٌ مِنْ بَنِي فُلاَنٍ ‏"‏ ‏.‏ فَلَمْ يُجِبْهُ أَحَدٌ ثُمَّ قَالَ ‏"‏ هَا هُنَا أَحَدٌ مِنْ بَنِي فُلاَنٍ ‏"‏ ‏.‏ فَلَمْ يُجِبْهُ أَحَدٌ ثُمَّ قَالَ ‏"‏ هَا هُنَا أَحَدٌ مِنْ بَنِي فُلاَنٍ ‏"‏ ‏.‏ فَقَامَ رَجُلٌ فَقَالَ أَنَا يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ صلى الله عليه وسلم ‏"‏ مَا مَنَعَكَ أَنْ تُجِيبَنِي فِي الْمَرَّتَيْنِ الأُولَيَيْنِ أَمَا إِنِّي لَمْ أُنَوِّهْ بِكُمْ إِلاَّ خَيْرًا إِنَّ صَاحِبَكُمْ مَأْسُورٌ بِدَيْنِهِ ‏"‏ ‏.‏ فَلَقَدْ رَأَيْتُهُ أَدَّى عَنْهُ حَتَّى مَا بَقِيَ أَحَدٌ يَطْلُبُهُ بِشَىْءٍ ‏.‏ قَالَ أَبُو دَاوُدَ سَمْعَانُ بْنُ مُشَنَّجٍ ‏.‏\hadithno{3341}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Samurah: The Messenger of Allah (ﷺ) addressed us and said: Is here any one of such and such tribe present? But no one replied. He again asked: Is here any one of such and such tribe present? But no one replied. He again asked: Is here any one of such and such tribe? Then a man stood and said: I am (here), Messenger of Allah. He said: What prevented you from replying the first two times? I wish to tell you something good. Your companion has been detained (from entering Paradise) on account of his debt. Then I saw him that he paid off all his debt on his behalf and there remained no one to demand from him anything. Abu Dawud said: The name of the narrator Sam'an is Sam'an b. Mushannaj}}
\hadithdefcmd{abudawud}{3342}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْمَهْرِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، حَدَّثَنِي سَعِيدُ بْنُ أَبِي أَيُّوبَ، أَنَّهُ سَمِعَ أَبَا عَبْدِ اللَّهِ الْقُرَشِيَّ، يَقُولُ سَمِعْتُ أَبَا بُرْدَةَ بْنَ أَبِي مُوسَى الأَشْعَرِيَّ، يَقُولُ عَنْ أَبِيهِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ إِنَّ أَعْظَمَ الذُّنُوبِ عِنْدَ اللَّهِ أَنْ يَلْقَاهُ بِهَا عَبْدٌ - بَعْدَ الْكَبَائِرِ الَّتِي نَهَى اللَّهُ عَنْهَا - أَنْ يَمُوتَ رَجُلٌ وَعَلَيْهِ دَيْنٌ لاَ يَدَعُ لَهُ قَضَاءً ‏"‏ ‏.‏\hadithno{3342}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuMusa al-Ash'ari: The Prophet (ﷺ) said: After the grave sins which Allah has prohibited the greatest sin is that a man dies while he has debt due from him and does not leave anything to pay it off, and meets Him with it}}
\hadithdefcmd{abudawud}{3343}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُتَوَكِّلِ الْعَسْقَلاَنِيُّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ جَابِرٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لاَ يُصَلِّي عَلَى رَجُلٍ مَاتَ وَعَلَيْهِ دَيْنٌ فَأُتِيَ بِمَيِّتٍ فَقَالَ ‏"‏ أَعَلَيْهِ دَيْنٌ ‏"‏ ‏.‏ قَالُوا نَعَمْ دِينَارَانِ ‏.‏ قَالَ ‏"‏ صَلُّوا عَلَى صَاحِبِكُمْ ‏"‏ ‏.‏ فَقَالَ أَبُو قَتَادَةَ الأَنْصَارِيُّ هُمَا عَلَىَّ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ فَصَلَّى عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَلَمَّا فَتَحَ اللَّهُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ أَنَا أَوْلَى بِكُلِّ مُؤْمِنٍ مِنْ نَفْسِهِ فَمَنْ تَرَكَ دَيْنًا فَعَلَىَّ قَضَاؤُهُ وَمَنْ تَرَكَ مَالاً فَلِوَرَثَتِهِ ‏"‏ ‏.‏\hadithno{3343}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Jabir ibn Abdullah: The Messenger of Allah (ﷺ) would not say funeral prayer over a person who died while the debt was due from him. A dead Muslim was brought to him and he asked: Is there any debt due from him? They (the people) said: Yes, two dirhams. He said: Pray yourselves over your companion. Then AbuQatadah al-Ansari said: I shall pay them, Messenger of Allah. The Messenger of Allah (ﷺ) then prayed over him. When Allah granted conquests to the Messenger of Allah (ﷺ), he said: I am nearer to every believer than himself, so if anyone (dies and) leaves a debt, I shall be responsible for paying it; and if anyone leaves property, it goes to his heirs}}
\hadithdefcmd{abudawud}{3344}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ شَرِيكٍ، عَنْ سِمَاكٍ، عَنْ عِكْرِمَةَ، رَفَعَهُ - قَالَ عُثْمَانُ وَحَدَّثَنَا وَكِيعٌ، عَنْ شَرِيكٍ، عَنْ سِمَاكٍ، عَنْ عِكْرِمَةَ، - عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ قَالَ اشْتَرَى مِنْ عِيرٍ تَبِيعًا وَلَيْسَ عِنْدَهُ ثَمَنُهُ فَأُرْبِحَ فِيهِ فَبَاعَهُ فَتَصَدَّقَ بِالرِّبْحِ عَلَى أَرَامِلِ بَنِي عَبْدِ الْمُطَّلِبِ وَقَالَ لاَ أَشْتَرِي بَعْدَهَا شَيْئًا إِلاَّ وَعِنْدِي ثَمَنُهُ ‏.‏\hadithno{3344}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{A similar tradition has also been transmitted by Ibn 'Abbas though a different chain of narrators. This version says:"He (the Prophet) purchased a calf from a caravan, but he had no money with him. He then sold it with some profit and gave the profit in charity to the poor and widows of Banu 'Abd al-Muttalib. He then said: I shall not buy anything after this but only when I have money with me}}
\hadithdefcmd{abudawud}{3345}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَطْلُ الْغَنِيِّ ظُلْمٌ وَإِذَا أُتْبِعَ أَحَدُكُمْ عَلَى مَلِيءٍ فَلْيَتْبَعْ ‏"‏ ‏.‏\hadithno{3345}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2287) Sahih Muslim (1564)}\hadithtrans{Narrated Abu Hurairah:The Messenger of Allah (ﷺ) as saying: Delay in payment (of debt) by a rich man is injunctive, but when one of you is referred to a wealthy man, he should accept the reference}}
\hadithdefcmd{abudawud}{3346}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي رَافِعٍ، قَالَ اسْتَسْلَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَكْرًا فَجَاءَتْهُ إِبِلٌ مِنَ الصَّدَقَةِ فَأَمَرَنِي أَنْ أَقْضِيَ الرَّجُلَ بَكْرَهُ فَقُلْتُ لَمْ أَجِدْ فِي الإِبِلِ إِلاَّ جَمَلاً خِيَارًا رَبَاعِيًّا ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَعْطِهِ إِيَّاهُ فَإِنَّ خِيَارَ النَّاسِ أَحْسَنُهُمْ قَضَاءً ‏"‏ ‏.‏\hadithno{3346}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1600)}\hadithtrans{Narrated Abu Rafi':The Messenger of Allah (ﷺ) borrowed a young camel, and when the camels of the sadaqah (alms) came to him, he ordered me to pay the man his young camel. I said: I find only an excellent camel in its seventh year. So the Prophet (ﷺ) said: Give it to him, for the best person is he who discharges his debt in the best manner}}
\hadithdefcmd{abudawud}{3347}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا يَحْيَى، عَنْ مِسْعَرٍ، عَنْ مُحَارِبِ بْنِ دِثَارٍ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، قَالَ كَانَ لِي عَلَى النَّبِيِّ صلى الله عليه وسلم دَيْنٌ فَقَضَانِي وَزَادَنِي ‏.‏\hadithno{3347}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (443) Sahih Muslim (715 After 1599)}\hadithtrans{Narrated Jabir ibn Abdullah: The Prophet (ﷺ) owed me a debt and gave me something extra when he paid it}}
\hadithdefcmd{abudawud}{3348}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، عَنْ مَالِكٍ، وَعَنِ ابْنِ شِهَابٍ، عَنْ مَالِكِ بْنِ أَوْسٍ، عَنْ عُمَرَ، - رضى الله عنه - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الذَّهَبُ بِالذَّهَبِ رِبًا إِلاَّ هَاءَ وَهَاءَ وَالْبُرُّ بِالْبُرِّ رِبًا إِلاَّ هَاءَ وَهَاءَ وَالتَّمْرُ بِالتَّمْرِ رِبًا إِلاَّ هَاءَ وَهَاءَ وَالشَّعِيرُ بِالشَّعِيرِ رِبًا إِلاَّ هَاءَ وَهَاءَ ‏"‏ ‏.‏\hadithno{3348}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2174) Sahih Muslim (1586)}\hadithtrans{Narrated 'Umar:The Messenger of Allah (ﷺ) as saying: Gold for gold is interest unless both hand over on the spot ; wheat for wheat is interest unless both hand over on the spot ; dates for dates is interest unless both hand over on the spot ; barley for barley is interest unless both hand over on the spot}}
\hadithdefcmd{abudawud}{3349}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا بِشْرُ بْنُ عُمَرَ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ أَبِي الْخَلِيلِ، عَنْ مُسْلِمٍ الْمَكِّيِّ، عَنْ أَبِي الأَشْعَثِ الصَّنْعَانِيِّ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الذَّهَبُ بِالذَّهَبِ تِبْرُهَا وَعَيْنُهَا وَالْفِضَّةُ بِالْفِضَّةِ تِبْرُهَا وَعَيْنُهَا وَالْبُرُّ بِالْبُرِّ مُدْىٌ بِمُدْىٍ وَالشَّعِيرُ بِالشَّعِيرِ مُدْىٌ بِمُدْىٍ وَالتَّمْرُ بِالتَّمْرِ مُدْىٌ بِمُدْىٍ وَالْمِلْحُ بِالْمِلْحِ مُدْىٌ بِمُدْىٍ فَمَنْ زَادَ أَوِ ازْدَادَ فَقَدْ أَرْبَى وَلاَ بَأْسَ بِبَيْعِ الذَّهَبِ بِالْفِضَّةِ - وَالْفِضَّةُ أَكْثَرُهُمَا - يَدًا بِيَدٍ وَأَمَّا نَسِيئَةً فَلاَ وَلاَ بَأْسَ بِبَيْعِ الْبُرِّ بِالشَّعِيرِ وَالشَّعِيرُ أَكْثَرُهُمَا يَدًا بِيَدٍ وَأَمَّا نَسِيئَةً فَلاَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَى هَذَا الْحَدِيثَ سَعِيدُ بْنُ أَبِي عَرُوبَةَ وَهِشَامٌ الدَّسْتَوَائِيُّ عَنْ قَتَادَةَ عَنْ مُسْلِمِ بْنِ يَسَارٍ بِإِسْنَادِهِ ‏.‏\hadithno{3349}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Ubadah ibn as-Samit: The Messenger of Allah (ﷺ) said: Gold is to be paid for with gold, raw and coined, silver with silver, raw and coined (in equal weight), wheat with wheat in equal measure, barley with barley in equal measure, dates with dates in equal measure, salt by salt with equal measure; if anyone gives more or asks more, he has dealt in usury. But there is no harm in selling gold for silver and silver (for gold), in unequal weight, payment being made on the spot. Do not sell them if they are to be paid for later. There is no harm in selling wheat for barley and barley (for wheat) in unequal measure, payment being made on the spot. If the payment is to be made later, then do not sell them. Abu Dawud said: This tradition has also been transmitted by Sa'id b. Abi 'Arubah, Hisham al-Dastawa'i and Qatadah from Muslim b. Yasar through his chain}}
\hadithdefcmd{abudawud}{3350}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ خَالِدٍ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الأَشْعَثِ الصَّنْعَانِيِّ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا الْخَبَرِ يَزِيدُ وَيَنْقُصُ وَزَادَ قَالَ فَإِذَا اخْتَلَفَتْ هَذِهِ الأَصْنَافُ فَبِيعُوا كَيْفَ شِئْتُمْ إِذَا كَانَ يَدًا بِيَدٍ ‏.‏\hadithno{3350}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1587)}\hadithtrans{The tradition mentioned above has also been transmitted by 'Ubadah b. al-Samit through a different chain of transmitters with some alternation. This version adds:"He said: If these classes differ, sell as you wish if payment is made on the spot}}
\hadithdefcmd{abudawud}{3351}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَأَحْمَدُ بْنُ مَنِيعٍ قَالُوا حَدَّثَنَا ابْنُ الْمُبَارَكِ، ح وَحَدَّثَنَا ابْنُ الْعَلاَءِ، أَخْبَرَنَا ابْنُ الْمُبَارَكِ، عَنْ سَعِيدِ بْنِ يَزِيدَ، حَدَّثَنِي خَالِدُ بْنُ أَبِي عِمْرَانَ، عَنْ حَنَشٍ، عَنْ فَضَالَةَ بْنِ عُبَيْدٍ، قَالَ أُتِيَ النَّبِيُّ صلى الله عليه وسلم عَامَ خَيْبَرَ بِقِلاَدَةٍ فِيهَا ذَهَبٌ وَخَرَزٌ - قَالَ أَبُو بَكْرٍ وَابْنُ مَنِيعٍ فِيهَا خَرَزٌ مُعَلَّقَةٌ بِذَهَبٍ - ابْتَاعَهَا رَجُلٌ بِتِسْعَةِ دَنَانِيرَ أَوْ بِسَبْعَةِ دَنَانِيرَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لاَ حَتَّى تُمَيِّزَ بَيْنَهُ وَبَيْنَهُ ‏"‏ ‏.‏ فَقَالَ إِنَّمَا أَرَدْتُ الْحِجَارَةَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لاَ حَتَّى تُمَيِّزَ بَيْنَهُمَا ‏"‏ ‏.‏ قَالَ فَرَدَّهُ حَتَّى مُيِّزَ بَيْنَهُمَا ‏.‏ وَقَالَ ابْنُ عِيسَى أَرَدْتُ التِّجَارَةَ ‏.‏ قَالَ أَبُو دَاوُدَ وَكَانَ فِي كِتَابِهِ الْحِجَارَةُ فَغَيَّرَهُ فَقَالَ التِّجَارَةَ ‏.‏\hadithno{3351}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1591)}\hadithtrans{Narrated Fudalah ibn Ubayd: The Prophet (ﷺ) was brought a necklace in which there were gold and pearls. (The narrators AbuBakr and (Ahmad) Ibn Mani' said: The pearls were set with gold in it, and a man bought it for nine or seven dinars.) The Prophet (ﷺ) said: (It must not be sold) till the contents are considered separately. The narrator said: He returned it till the contents were considered separately. The narrator Ibn Asa said: By this I intended trade. Abu Dawud said: The word hijarah (stone) was recorded in his note-book before, but he changed it and narrated tijarah (trade)}}
\hadithdefcmd{abudawud}{3352}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ أَبِي شُجَاعٍ، سَعِيدِ بْنِ يَزِيدَ عَنْ خَالِدِ بْنِ أَبِي عِمْرَانَ، عَنْ حَنَشٍ الصَّنْعَانِيِّ، عَنْ فَضَالَةَ بْنِ عُبَيْدٍ، قَالَ اشْتَرَيْتُ يَوْمَ خَيْبَرَ قِلاَدَةً بِاثْنَىْ عَشَرَ دِينَارًا فِيهَا ذَهَبٌ وَخَرَزٌ فَفَصَّلْتُهَا فَوَجَدْتُ فِيهَا أَكْثَرَ مِنَ اثْنَىْ عَشَرَ دِينَارًا فَذَكَرْتُ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ لاَ تُبَاعُ حَتَّى تُفَصَّلَ ‏"‏ ‏.‏\hadithno{3352}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1591)}\hadithtrans{Narrated Fudalah bin 'Ubaid:At the battle of Khaibar I bought a necklace in which there were gold and pearls for twelve dinars. I separated them and found that its worth was more than twelve dinars. So I mentioned that to the Prophet (ﷺ) who said: It must not be sold till the contents are considered separately}}
\hadithdefcmd{abudawud}{3353}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ أَبِي جَعْفَرٍ، عَنِ الْجُلاَحِ أَبِي كَثِيرٍ، حَدَّثَنِي حَنَشٌ الصَّنْعَانِيُّ، عَنْ فَضَالَةَ بْنِ عُبَيْدٍ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمَ خَيْبَرَ نُبَايِعُ الْيَهُودَ الأُوقِيَّةَ مِنَ الذَّهَبِ بِالدِّينَارِ ‏.‏ قَالَ غَيْرُ قُتَيْبَةَ بِالدِّينَارَيْنِ وَالثَّلاَثَةِ ‏.‏ ثُمَّ اتَّفَقَا فَقَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَبِيعُوا الذَّهَبَ بِالذَّهَبِ إِلاَّ وَزْنًا بِوَزْنٍ ‏"‏ ‏.‏\hadithno{3353}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1591)}\hadithtrans{Narrated Fudalah bin 'Ubaid:We were with the Messenger of Allah (ﷺ) at the battle of Khaibar. We were selling to the Jews one uqiyah of gold for one dinar. The narrators other than Qutaibah said: "for two or three dinars." Then both the versions agreed. The Messenger of Allah (ﷺ) said: Do not sell gold except with equal weight}}
\hadithdefcmd{abudawud}{3354}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، وَمُحَمَّدُ بْنُ مَحْبُوبٍ، - الْمَعْنَى وَاحِدٌ - قَالاَ حَدَّثَنَا حَمَّادٌ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عُمَرَ، قَالَ كُنْتُ أَبِيعُ الإِبِلَ بِالْبَقِيعِ فَأَبِيعُ بِالدَّنَانِيرِ وَآخُذُ الدَّرَاهِمَ وَأَبِيعُ بِالدَّرَاهِمِ وَآخُذُ الدَّنَانِيرَ آخُذُ هَذِهِ مِنْ هَذِهِ وَأُعْطِي هَذِهِ مِنْ هَذِهِ فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهُوَ فِي بَيْتِ حَفْصَةَ فَقُلْتُ يَا رَسُولَ اللَّهِ رُوَيْدَكَ أَسْأَلُكَ إِنِّي أَبِيعُ الإِبِلَ بِالْبَقِيعِ فَأَبِيعُ بِالدَّنَانِيرِ وَآخُذُ الدَّرَاهِمَ وَأَبِيعُ بِالدَّرَاهِمِ وَآخُذُ الدَّنَانِيرَ آخُذُ هَذِهِ مِنْ هَذِهِ وَأُعْطِي هَذِهِ مِنْ هَذِهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ بَأْسَ أَنْ تَأْخُذَهَا بِسَعْرِ يَوْمِهَا مَا لَمْ تَفْتَرِقَا وَبَيْنَكُمَا شَىْءٌ ‏"‏ ‏.‏\hadithno{3354}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Umar: I used to sell camels at al-Baqi for dinars and take dirhams for them, and sell for dirhams and take dinars for them. I would take these for these and give these for these. I went to the Messenger of Allah (ﷺ) who was in the house of Hafsah. I said: Messenger of Allah , take it easy, I shall ask you (a question): I sell camels at al-Baqi'. I sell (them) for dinars and take dirhams and I sell for dirhams and take dinars. I take these for these, and give these for these. The Messenger of Allah (ﷺ) then said: There is no harm in taking them at the current rate so long as you do not separate leaving something to be settled}}
\hadithdefcmd{abudawud}{3355}{حَدَّثَنَا حُسَيْنُ بْنُ الأَسْوَدِ، حَدَّثَنَا عُبَيْدُ اللَّهِ، أَخْبَرَنَا إِسْرَائِيلُ، عَنْ سِمَاكٍ، بِإِسْنَادِهِ وَمَعْنَاهُ وَالأَوَّلُ أَتَمُّ لَمْ يَذْكُرْ ‏ "‏ بِسِعْرِ يَوْمِهَا ‏"‏ ‏.‏\hadithno{3355}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Hasan}\hadithtrans{The tradition mentioned above has also been transmitted by Simak (b. Harb) with a different chain of narrators and to the same effect. The first version is more perfect. It does not mention the words "at the current rate}}
\hadithdefcmd{abudawud}{3356}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ الْحَيَوَانِ بِالْحَيَوَانِ نَسِيئَةً ‏.‏\hadithno{3356}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Samurah (ibn Jundub): The Prophet (ﷺ) forbade selling animals for animals when payment was to be made at a later date}}
\hadithdefcmd{abudawud}{3357}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ يَزِيدَ بْنَ أَبِي حَبِيبٍ، عَنْ مُسْلِمِ بْنِ جُبَيْرٍ، عَنْ أَبِي سُفْيَانَ، عَنْ عَمْرِو بْنِ حَرِيشٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَهُ أَنْ يُجَهِّزَ جَيْشًا فَنَفِدَتِ الإِبِلُ فَأَمَرَهُ أَنْ يَأْخُذَ فِي قِلاَصِ الصَّدَقَةِ فَكَانَ يَأْخُذُ الْبَعِيرَ بِالْبَعِيرَيْنِ إِلَى إِبِلِ الصَّدَقَةِ ‏.‏\hadithno{3357}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Messenger of Allah (ﷺ) commanded him to equip an army, but the camels were insufficient. So he commanded him to keep back the young camels of sadaqah, and he was taking a camel to be replaced by two when the camels of sadaqah came}}
\hadithdefcmd{abudawud}{3358}{حَدَّثَنَا يَزِيدُ بْنُ خَالِدٍ الْهَمْدَانِيُّ، وَقُتَيْبَةُ بْنُ سَعِيدٍ الثَّقَفِيُّ، أَنَّ اللَّيْثَ، حَدَّثَهُمْ عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم اشْتَرَى عَبْدًا بِعَبْدَيْنِ ‏.‏\hadithno{3358}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1602)}\hadithtrans{Narrated Jabir:The Prophet (ﷺ) bought a slave for two slaves}}
\hadithdefcmd{abudawud}{3359}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ، أَنَّ زَيْدًا أَبَا عَيَّاشٍ، أَخْبَرَهُ أَنَّهُ، سَأَلَ سَعْدَ بْنَ أَبِي وَقَّاصٍ عَنِ الْبَيْضَاءِ، بِالسُّلْتِ فَقَالَ لَهُ سَعْدٌ أَيُّهُمَا أَفْضَلُ قَالَ الْبَيْضَاءُ ‏.‏ فَنَهَاهُ عَنْ ذَلِكَ وَقَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُسْأَلُ عَنْ شِرَاءِ التَّمْرِ بِالرُّطَبِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَيَنْقُصُ الرُّطَبُ إِذَا يَبِسَ ‏"‏ ‏.‏ قَالُوا نَعَمْ فَنَهَاهُ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ إِسْمَاعِيلُ بْنُ أُمَيَّةَ نَحْوَ مَالِكٍ ‏.‏\hadithno{3359}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Zayd Abu 'Ayyash asked Sa'd ibn Abi Waqqas about the sale of the soft and white kind of wheat for barley. Sa'd said:Which of them is better? He replied: Soft and white kind of wheat. So he forbade him from it and said: I heard the Messenger of Allah (sawa) say, when he was asked about buying dry dates for fresh. The Messenger of Allah (sawa) said: Are fresh dates diminished when they become dry? The (the people) replied: Yes. So the Messenger of Allah (ﷺ) forbade that. Abu Dawud said: A similar tradition has also been transmitted by Isma'il b. Umayyah}}
\hadithdefcmd{abudawud}{3360}{حَدَّثَنَا الرَّبِيعُ بْنُ نَافِعٍ أَبُو تَوْبَةَ، حَدَّثَنَا مُعَاوِيَةُ، - يَعْنِي ابْنَ سَلاَّمٍ - عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَنَّ أَبَا عَيَّاشٍ، أَخْبَرَهُ أَنَّهُ، سَمِعَ سَعْدَ بْنَ أَبِي وَقَّاصٍ، يَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ بَيْعِ الرُّطَبِ بِالتَّمْرِ نَسِيئَةً ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ عِمْرَانُ بْنُ أَبِي أَنَسٍ عَنْ مَوْلًى لِبَنِي مَخْزُومٍ عَنْ سَعْدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{3360}\hadithgrade{Al-Albani: Shadh; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Sa'd ibn Abi Waqqas: The Messenger of Allah (ﷺ) forbade to sell fresh dates for dry dates when payment is made at a later date. Abu Dawud said: The tradition mentioned above has also been transmitted by Sa'd (b. Abi Waqqas) from the Prophet (ﷺ) through a different chain of narrators in a similar way}}
\hadithdefcmd{abudawud}{3361}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ أَبِي زَائِدَةَ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ الثَّمَرِ بِالتَّمْرِ كَيْلاً وَعَنْ بَيْعِ الْعِنَبِ بِالزَّبِيبِ كَيْلاً وَعَنْ بَيْعِ الزَّرْعِ بِالْحِنْطَةِ كَيْلاً ‏.‏\hadithno{3361}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2171، 2205) Sahih Muslim (1542)}\hadithtrans{Narrated Ibn 'Umar:The Prophet (ﷺ) forbade the sale of fruits on the tree for fruits by measure, and sale of grapes for raisins by measure, and sale of harvest for wheat by measure}}
\hadithdefcmd{abudawud}{3362}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي خَارِجَةُ بْنُ زَيْدِ بْنِ ثَابِتٍ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم رَخَّصَ فِي بَيْعِ الْعَرَايَا بِالتَّمْرِ وَالرُّطَبِ ‏.‏\hadithno{3362}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Zaid b. Thabit:The Prophet (ﷺ) gave license for the sale of 'araya for dried dates and fresh dates}}
\hadithdefcmd{abudawud}{3363}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ بَشِيرِ بْنِ يَسَارٍ، عَنْ سَهْلِ بْنِ أَبِي حَثْمَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ الثَّمَرِ بِالتَّمْرِ وَرَخَّصَ فِي الْعَرَايَا أَنْ تُبَاعَ بِخَرْصِهَا يَأْكُلُهَا أَهْلُهَا رُطَبًا ‏.‏\hadithno{3363}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2191) Sahih Muslim (1540)}\hadithtrans{Narrated Sahl b. Abi Khathmah:The Messenger of Allah (ﷺ) forbade the sale of fruits for dried dates, but gave license regarding the 'araya for its sale on the basis of a calculation of their amount. But those who buy them can eat them when fresh}}
\hadithdefcmd{abudawud}{3364}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا مَالِكٌ، عَنْ دَاوُدَ بْنِ الْحُصَيْنِ، عَنْ مَوْلَى ابْنِ أَبِي أَحْمَدَقَالَ أَبُو دَاوُدَ وَقَالَ لَنَا الْقَعْنَبِيُّ فِيمَا قَرَأَ عَلَى مَالِكٍ عَنْ أَبِي سُفْيَانَ وَاسْمُهُ قُزْمَانُ مَوْلَى ابْنِ أَبِي أَحْمَدَ عَنْ أَبِي هُرَيْرَةَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَخَّصَ فِي بَيْعِ الْعَرَايَا فِيمَا دُونَ خَمْسَةِ أَوْسُقٍ أَوْ فِي خَمْسَةِ أَوْسُقٍ شَكَّ دَاوُدُ بْنُ الْحُصَيْنِ ‏.‏ قَالَ أَبُو دَاوُدَ حَدِيثُ جَابِرٍ إِلَى أَرْبَعَةِ أَوْسُقٍ ‏.‏\hadithno{3364}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2382) Sahih Muslim (1541)}\hadithtrans{Narrated Abu Hurairah: The Messenger of Allah (ﷺ) gave license regarding the sale of 'araya when the amount was less then five wasqs or five wasqs. Dawud b. al-Husain was doubtful. Abu Dawud said: The tradition by Jabir indicates up to four wasqs}}
\hadithdefcmd{abudawud}{3365}{حَدَّثَنَا أَحْمَدُ بْنُ سَعِيدٍ الْهَمْدَانِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ عَبْدِ رَبِّهِ بْنِ سَعِيدٍ الأَنْصَارِيِّ، أَنَّهُ قَالَ الْعَرِيَّةُ الرَّجُلُ يُعْرِي الرَّجُلَ النَّخْلَةَ أَوِ الرَّجُلُ يَسْتَثْنِي مِنْ مَالِهِ النَّخْلَةَ أَوْ الاِثْنَتَيْنِ يَأْكُلُهَا فَيَبِيعُهَا بِتَمْرٍ ‏.‏\hadithno{3365}\hadithgrade{Al-Albani: Sahih Isnaad Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abd Rabbihi b. Sa'id al-Ansari said:'Ariyyah means that a man gives another man a palm-tree on loan, or it means that reserves one or two palm-trees from his property for his personal use, then he sells for dried dates}}
\hadithdefcmd{abudawud}{3366}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ عَبْدَةَ، عَنِ ابْنِ إِسْحَاقَ، قَالَ الْعَرَايَا أَنْ يَهَبَ الرَّجُلُ، لِلرَّجُلِ النَّخَلاَتِ فَيَشُقَّ عَلَيْهِ أَنْ يَقُومَ عَلَيْهَا فَيَبِيعَهَا بِمِثْلِ خَرْصِهَا ‏.‏\hadithno{3366}\hadithgrade{Al-Albani: Sahih Isnaad Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn Ishaq said:'Araya means that a man lends another man some palm-trees, but he (the owner) feels inconvenient that the man looks after the trees (by frequent visits). He (the borrower) sells them (to the owner) by calculation}}
\hadithdefcmd{abudawud}{3367}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ الثِّمَارِ حَتَّى يَبْدُوَ صَلاَحُهَا نَهَى الْبَائِعَ وَالْمُشْتَرِيَ ‏.‏\hadithno{3367}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2194) Sahih Muslim (1534)}\hadithtrans{Narrated 'Abdullah bin 'Umar:The Messenger of Allah (ﷺ) forbade the sale of fruits till they were clearly in good condition, forbidding it both to the seller and to the buyer}}
\hadithdefcmd{abudawud}{3368}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا ابْنُ عُلَيَّةَ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ النَّخْلِ حَتَّى يَزْهُوَ وَعَنِ السُّنْبُلِ حَتَّى يَبْيَضَّ وَيَأْمَنَ الْعَاهَةَ نَهَى الْبَائِعَ وَالْمُشْتَرِيَ ‏.‏\hadithno{3368}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1535)}\hadithtrans{Narrated Ibn 'Umar:The Messenger of Allah (ﷺ) forbade selling palm-trees till the dates began to ripen, and ears of corn till they were white and were safe from blight, forbidding it both to the buyer and to the seller}}
\hadithdefcmd{abudawud}{3369}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ النَّمَرِيُّ، حَدَّثَنَا شُعْبَةُ، عَنْ يَزِيدَ بْنِ خُمَيْرٍ، عَنْ مَوْلًى، لِقُرَيْشٍ عَنْ أَبِي هُرَيْرَةَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ بَيْعِ الْغَنَائِمِ حَتَّى تُقْسَمَ وَعَنْ بَيْعِ النَّخْلِ حَتَّى تُحْرَزَ مِنْ كُلِّ عَارِضٍ وَأَنْ يُصَلِّيَ الرَّجُلُ بِغَيْرِ حِزَامٍ ‏.‏\hadithno{3369}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuHurayrah: The Messenger of Allah (ﷺ) forbade to sell spoils of war till they are appointed, and to sell palm trees till they are safe from every blight, and a man praying without tying belt}}
\hadithdefcmd{abudawud}{3370}{حَدَّثَنَا أَبُو بَكْرٍ، مُحَمَّدُ بْنُ خَلاَّدٍ الْبَاهِلِيُّ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ سَلِيمِ بْنِ حَيَّانَ، أَخْبَرَنَا سَعِيدُ بْنُ مِينَاءَ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ تُبَاعَ الثَّمَرَةُ حَتَّى تُشَقِّحَ ‏.‏ قِيلَ وَمَا تُشَقِّحُ قَالَ تَحْمَارُّ وَتَصْفَارُّ وَيُؤْكَلُ مِنْهَا ‏.‏\hadithno{3370}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2196) Sahih Muslim (1536 After 1543)}\hadithtrans{Narrated Jabir bin ‘Abdullah :The Messenger of Allah (ﷺ) forbade the sale of fruits until they are ripened (tushqihah). He was asked: What do you mean by their ripening (ishqah)? He replied: They become red or yellow, and they are eaten}}
\hadithdefcmd{abudawud}{3371}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا أَبُو الْوَلِيدِ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ الْعِنَبِ حَتَّى يَسْوَدَّ وَعَنْ بَيْعِ الْحَبِّ حَتَّى يَشْتَدَّ ‏.‏\hadithno{3371}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Anas ibn Malik: The Prophet (ﷺ) forbade the sale of grapes till they became black and the sale of grain till it had become hard}}
\hadithdefcmd{abudawud}{3372}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَنْبَسَةُ بْنُ خَالِدٍ، حَدَّثَنِي يُونُسُ، قَالَ سَأَلْتُ أَبَا الزِّنَادِ عَنْ بَيْعِ الثَّمَرِ، قَبْلَ أَنْ يَبْدُوَ، صَلاَحُهُ وَمَا ذُكِرَ فِي ذَلِكَ فَقَالَ كَانَ عُرْوَةُ بْنُ الزُّبَيْرِ يُحَدِّثُ عَنْ سَهْلِ بْنِ أَبِي حَثْمَةَ عَنْ زَيْدِ بْنِ ثَابِتٍ قَالَ كَانَ النَّاسُ يَتَبَايَعُونَ الثِّمَارَ قَبْلَ أَنْ يَبْدُوَ صَلاَحُهَا فَإِذَا جَدَّ النَّاسُ وَحَضَرَ تَقَاضِيهِمْ قَالَ الْمُبْتَاعُ قَدْ أَصَابَ الثَّمَرَ الدُّمَانُ وَأَصَابَهُ قُشَامٌ وَأَصَابَهُ مُرَاضٌ عَاهَاتٌ يَحْتَجُّونَ بِهَا فَلَمَّا كَثُرَتْ خُصُومَتُهُمْ عِنْدَ النَّبِيِّ صلى الله عليه وسلم قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم كَالْمَشُورَةِ يُشِيرُ بِهَا ‏ "‏ فَإِمَّا لاَ فَلاَ تَتَبَايَعُوا الثَّمَرَةَ حَتَّى يَبْدُوَ صَلاَحُهَا ‏"‏ ‏.‏ لِكَثْرَةِ خُصُومَتِهِمْ وَاخْتِلاَفِهِمْ ‏.‏\hadithno{3372}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Yunus said:I asked Abu Zinad about the sale of fruits before they were clearly in good condition, and what was said about it. He replied: Urwah ibn az-Zubayr reports a tradition from Sahl ibn Abi Hathmah on the authority of Zayd ibn Thabit who said: The people used to sell fruits before they were clearly in good condition. When the people cut off the fruits, and were demanded to pay the price, the buyer said: The fruits have been smitten by duman, qusham and murad fruit diseases on which they used to dispute. When their disputes which were brought to the Prophet (ﷺ) increased, the Messenger of Allah (ﷺ) said to them as an advice: No, do not sell fruits till they are in good condition, due to a large number of their disputes and differences}}
\hadithdefcmd{abudawud}{3373}{حَدَّثَنَا إِسْحَاقُ بْنُ إِسْمَاعِيلَ الطَّالْقَانِيُّ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ الثَّمَرِ حَتَّى يَبْدُوَ صَلاَحُهُ وَلاَ يُبَاعُ إِلاَّ بِالدِّينَارِ أَوْ بِالدِّرْهَمِ إِلاَّ الْعَرَايَا ‏.‏\hadithno{3373}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2381) Sahih Muslim (1536 After 1543)}\hadithtrans{Narrated Jabir ibn Abdullah: The Prophet (ﷺ) forbade the sale of fruits till they were clearly in good condition , and (ordered that) they should not be sold but for dinar or dirham except Araya}}
\hadithdefcmd{abudawud}{3374}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، وَيَحْيَى بْنُ مَعِينٍ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ حُمَيْدٍ الأَعْرَجِ، عَنْ سُلَيْمَانَ بْنِ عَتِيقٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ السِّنِينَ وَوَضَعَ الْجَوَائِحَ ‏.‏ قَالَ أَبُو دَاوُدَ لَمْ يَصِحَّ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي الثُّلُثِ شَىْءٌ وَهُوَ رَأْىُ أَهْلِ الْمَدِينَةِ ‏.‏\hadithno{3374}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1554 After 1555)}\hadithtrans{Narrated Jabir ibn Abdullah: The Prophet (ﷺ) forbade selling fruits years ahead, and commanded that unforeseen loss be remitted in respect of what is affected by blight. Abu Dawud said: The attribution of the tradition regarding the effect of blight is one-third of the produce to the Prophet (ﷺ) is not correct. This is the opinion of the people of Medina}}
\hadithdefcmd{abudawud}{3375}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ أَبِي الزُّبَيْرِ، وَسَعِيدِ بْنِ مِينَاءَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنِ الْمُعَاوَمَةِ وَقَالَ أَحَدُهُمَا بَيْعِ السِّنِينَ ‏.‏\hadithno{3375}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1554)}\hadithtrans{Narrated Jabir bin ‘Abdullah :The Prophet (ﷺ) forbade sale of fruits for a number of years. One of the two narrators (Abu al-Zubair and Sa'id b. Mina') mentioned the words "sale for years" (bai' al-sinin instead of al-mu'awamah)}}
\hadithdefcmd{abudawud}{3376}{حَدَّثَنَا أَبُو بَكْرٍ، وَعُثْمَانُ، ابْنَا أَبِي شَيْبَةَ قَالاَ حَدَّثَنَا ابْنُ إِدْرِيسَ، عَنْ عُبَيْدِ اللَّهِ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ الْغَرَرِ - زَادَ عُثْمَانُ - وَالْحَصَاةِ ‏.‏\hadithno{3376}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1513)}\hadithtrans{Narrated Abu Hurairah:The Prophet (ﷺ) forbade the type of sale which involves risk (or uncertainty) and a transaction determined by throwing stones}}
\hadithdefcmd{abudawud}{3377}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَأَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، - وَهَذَا لَفْظُهُ - قَالاَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عَطَاءِ بْنِ يَزِيدَ اللَّيْثِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ بَيْعَتَيْنِ وَعَنْ لِبْسَتَيْنِ أَمَّا الْبَيْعَتَانِ فَالْمُلاَمَسَةُ وَالْمُنَابَذَةُ وَأَمَّا اللِّبْسَتَانِ فَاشْتِمَالُ الصَّمَّاءِ وَأَنْ يَحْتَبِيَ الرَّجُلُ فِي ثَوْبٍ وَاحِدٍ كَاشِفًا عَنْ فَرْجِهِ أَوْ لَيْسَ عَلَى فَرْجِهِ مِنْهُ شَىْءٌ ‏.‏\hadithno{3377}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6284) Sahih Muslim (1512)}\hadithtrans{Narrated Abu Sa’id Al Khudri :The Prophet (ﷺ) forbade two types of business transactions and two ways of dressing. The two types of business transactions are mulamasah and munabadhah. As regards the two ways of dressing, they are the wrapping of the samma', and that when a man wraps himself up in a single garment while sitting in such a way that he does not cover his private parts or there is no garment on his private parts}}
\hadithdefcmd{abudawud}{3378}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عَطَاءِ بْنِ يَزِيدَ اللَّيْثِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا الْحَدِيثِ زَادَ وَاشْتِمَالُ الصَّمَّاءِ أَنْ يَشْتَمِلَ فِي ثَوْبٍ وَاحِدٍ يَضَعُ طَرَفَىِ الثَّوْبِ عَلَى عَاتِقِهِ الأَيْسَرِ وَيُبْرِزُ شِقَّهُ الأَيْمَنَ وَالْمُنَابَذَةُ أَنْ يَقُولَ إِذَا نَبَذْتُ إِلَيْكَ هَذَا الثَّوْبَ فَقَدْ وَجَبَ الْبَيْعُ وَالْمُلاَمَسَةُ أَنْ يَمَسَّهُ بِيَدِهِ وَلاَ يَنْشُرُهُ وَلاَ يُقَلِّبُهُ فَإِذَا مَسَّهُ وَجَبَ الْبَيْعُ ‏.‏\hadithno{3378}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned above has also been reported by Abu Sa'id al-Khudri from the Prophet (ﷺ) through a different chain of narrators. This version adds:"Wearing the samma' means that a man puts his garment over his left shoulder and keeps his right side uncovered. Munabadhah means that a man says (to another): If I throw this garment to you, the sale will be certain. Mulamasah means that a man touches it (another's garment) with his hand and neither he unfolds it nor turns it over. When he touched it, the sale becomes binding}}
\hadithdefcmd{abudawud}{3379}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَنْبَسَةُ بْنُ خَالِدٍ، حَدَّثَنَا يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عَامِرُ بْنُ سَعْدِ بْنِ أَبِي وَقَّاصٍ، أَنَّ أَبَا سَعِيدٍ الْخُدْرِيَّ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم بِمَعْنَى حَدِيثِ سُفْيَانَ وَعَبْدِ الرَّزَّاقِ جَمِيعًا ‏.‏\hadithno{3379}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5820) Sahih Muslim (1512)}\hadithtrans{The tradition mentioned above has also been transmitted by Abu Said al-Khudri through a different chain of narrators from the Messenger of Allah (ﷺ) to the same effect as narrated by both Sufyan and 'Abd al-Razzaq}}
\hadithdefcmd{abudawud}{3380}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ حَبَلِ الْحَبَلَةِ ‏.‏\hadithno{3380}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2143) Sahih Muslim (1514)}\hadithtrans{Narrated Ibn 'Umar:The Messenger of Allah (ﷺ) forbade the transaction called habal al-habalah}}
\hadithdefcmd{abudawud}{3381}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ وَقَالَ حَبَلُ الْحَبَلَةِ أَنْ تُنْتَجَ النَّاقَةُ بَطْنَهَا ثُمَّ تَحْمِلُ الَّتِي نُتِجَتْ ‏.‏\hadithno{3381}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (3843) Sahih Muslim (1514)}\hadithtrans{A similar tradition has also been narrated by Ibn 'Umar from the Prophet (ﷺ) through a different chain of transmitters. He said:Habal al-habalah means that a she-camel delivers an offspring and then the offspring which it delivers becomes pregnant}}
\hadithdefcmd{abudawud}{3382}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا صَالِحُ أَبُو عَامِرٍ، - قَالَ أَبُو دَاوُدَ كَذَا قَالَ مُحَمَّدٌ - حَدَّثَنَا شَيْخٌ، مِنْ بَنِي تَمِيمٍ قَالَ خَطَبَنَا عَلِيُّ بْنُ أَبِي طَالِبٍ - أَوْ قَالَ قَالَ عَلِيٌّ قَالَ ابْنُ عِيسَى هَكَذَا حَدَّثَنَا هُشَيْمٌ، - قَالَ سَيَأْتِي عَلَى النَّاسِ زَمَانٌ عَضُوضٌ يَعَضُّ الْمُوسِرُ عَلَى مَا فِي يَدَيْهِ وَلَمْ يُؤْمَرْ بِذَلِكَ قَالَ اللَّهُ تَعَالَى ‏\{‏ وَلاَ تَنْسَوُا الْفَضْلَ بَيْنَكُمْ ‏\}‏ وَيُبَايَعُ الْمُضْطَرُّونَ وَقَدْ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ بَيْعِ الْمُضْطَرِّ وَبَيْعِ الْغَرَرِ وَبَيْعِ الثَّمَرَةِ قَبْلَ أَنْ تُدْرِكَ ‏.‏\hadithno{3382}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ali ibn AbuTalib: A time is certainly coming to mankind when people will bite each other and a rich man will hold fast, what he has in his possession (i.e. his property), though he was not commanded for that. Allah, Most High, said: "And do not forget liberality between yourselves." The men who are forced will contract sale while the Prophet (ﷺ) forbade forced contract, one which involves some uncertainty, and the sale of fruit before it is ripe}}
\hadithdefcmd{abudawud}{3383}{حَدَّثَنَا مُحَمَّدُ بْنُ سُلَيْمَانَ الْمِصِّيصِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ الزِّبْرِقَانِ، عَنْ أَبِي حَيَّانَ التَّيْمِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، رَفَعَهُ قَالَ ‏ "‏ إِنَّ اللَّهَ يَقُولُ أَنَا ثَالِثُ الشَّرِيكَيْنِ، مَا لَمْ يَخُنْ أَحَدُهُمَا صَاحِبَهُ فَإِذَا خَانَهُ خَرَجْتُ مِنْ بَيْنِهِمَا ‏"‏ ‏.‏\hadithno{3383}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: The Messenger of Allah (ﷺ) having said: Allah, Most High, says: "I make a third with two partners as long as one of them does not cheat the other, but when he cheats him, I depart from them}}
\hadithdefcmd{abudawud}{3384}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا سُفْيَانُ، عَنْ شَبِيبِ بْنِ غَرْقَدَةَ، حَدَّثَنِي الْحَىُّ، عَنْ عُرْوَةَ، - يَعْنِي ابْنَ أَبِي الْجَعْدِ الْبَارِقِيِّ - قَالَ أَعْطَاهُ النَّبِيُّ صلى الله عليه وسلم دِينَارًا يَشْتَرِي بِهِ أُضْحِيَةً أَوْ شَاةً فَاشْتَرَى شَاتَيْنِ فَبَاعَ إِحْدَاهُمَا بِدِينَارٍ فَأَتَاهُ بِشَاةٍ وَدِينَارٍ فَدَعَا لَهُ بِالْبَرَكَةِ فِي بَيْعِهِ فَكَانَ لَوِ اشْتَرَى تُرَابًا لَرَبِحَ فِيهِ ‏.‏\hadithno{3384}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari (3642)}\hadithtrans{Narrated Urwah ibn AbulJa'd al-Bariqi: The Prophet (ﷺ) gave him a dinar to buy a sacrificial animal or a sheep. He bought two sheep, sold one of them for a dinar, and brought him a sheep and dinar. So he invoked a blessing on him in his business dealing, and he was such that if had he bought dust he would have made a profit from it}}
\hadithdefcmd{abudawud}{3385}{حَدَّثَنَا الْحَسَنُ بْنُ الصَّبَّاحِ، حَدَّثَنَا أَبُو الْمُنْذِرِ، حَدَّثَنَا سَعِيدُ بْنُ زَيْدٍ، - هُوَ أَخُو حَمَّادِ بْنِ زَيْدٍ - حَدَّثَنَا الزُّبَيْرُ بْنُ الْخِرِّيتِ، عَنْ أَبِي لَبِيدٍ، حَدَّثَنِي عُرْوَةُ الْبَارِقِيُّ، بِهَذَا الْخَبَرِ وَلَفْظُهُ مُخْتَلِفٌ ‏.‏\hadithno{3385}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{The tradition mentioned above has also been transmitted by 'Urwat al-Bariqi through a different chain of narrators. The wordings of this version are different from those of the previous one}}
\hadithdefcmd{abudawud}{3386}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ الْعَبْدِيُّ، أَخْبَرَنَا سُفْيَانُ، حَدَّثَنِي أَبُو حُصَيْنٍ، عَنْ شَيْخٍ، مِنْ أَهْلِ الْمَدِينَةِ عَنْ حَكِيمِ بْنِ حِزَامٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَ مَعَهُ بِدِينَارٍ يَشْتَرِي لَهُ أُضْحِيَةً فَاشْتَرَاهَا بِدِينَارٍ وَبَاعَهَا بِدِينَارَيْنِ فَرَجَعَ فَاشْتَرَى لَهُ أُضْحِيَةً بِدِينَارٍ وَجَاءَ بِدِينَارٍ إِلَى النَّبِيِّ صلى الله عليه وسلم فَتَصَدَّقَ بِهِ النَّبِيُّ صلى الله عليه وسلم وَدَعَا لَهُ أَنْ يُبَارَكَ لَهُ فِي تِجَارَتِهِ ‏.‏\hadithno{3386}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Hakim ibn Hizam: The Messenger of Allah (ﷺ) sent with him a dinar to buy a sacrificial animal for him. He bought a sheep for a dinar, sold it for two and then returned and bought a sacrificial animal for a dinar for him and brought the (extra) dinar to the Prophet (ﷺ). The Prophet (ﷺ) gave it as alms (sadaqah) and invoked blessing on him in his trading}}
\hadithdefcmd{abudawud}{3387}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا عُمَرُ بْنُ حَمْزَةَ، أَخْبَرَنَا سَالِمُ بْنُ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ مَنِ اسْتَطَاعَ مِنْكُمْ أَنْ يَكُونَ مِثْلَ صَاحِبِ فَرْقِ الأَرُزِّ فَلْيَكُنْ مِثْلَهُ ‏"‏ ‏.‏ قَالُوا وَمَنْ صَاحِبُ فَرْقِ الأَرُزِّ يَا رَسُولَ اللَّهِ فَذَكَرَ حَدِيثَ الْغَارِ حِينَ سَقَطَ عَلَيْهِمُ الْجَبَلُ فَقَالَ كُلُّ وَاحِدٍ مِنْهُمُ اذْكُرُوا أَحْسَنَ عَمَلِكُمْ قَالَ ‏"‏ وَقَالَ الثَّالِثُ اللَّهُمَّ إِنَّكَ تَعْلَمُ أَنِّي اسْتَأْجَرْتُ أَجِيرًا بِفَرْقِ أَرُزٍّ فَلَمَّا أَمْسَيْتُ عَرَضْتُ عَلَيْهِ حَقَّهُ فَأَبَى أَنْ يَأْخُذَهُ وَذَهَبَ فَثَمَّرْتُهُ لَهُ حَتَّى جَمَعْتُ لَهُ بَقَرًا وَرِعَاءَهَا فَلَقِيَنِي فَقَالَ أَعْطِنِي حَقِّي ‏.‏ فَقُلْتُ اذْهَبْ إِلَى تِلْكَ الْبَقَرِ وَرِعَائِهَا فَخُذْهَا فَذَهَبَ فَاسْتَاقَهَا ‏"‏ ‏.‏\hadithno{3387}\hadithgrade{Al-Albani: Munkar; Muhammad Muhyi Al-Din Abdul Hamid: Munkar; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Abd Allah b. 'Umar: I heard the Messenger of Allah (ﷺ) say: If any of you can become like the man who had a faraq of rice, he should become like him. They (the people) asked: Who is the man who had a faraq of rice with him, Messenger of Allah ? Thereupon he narrated the story of the cave when a hillock fell on them (three persons), each of them said: Mention any best work of yours. The narrator said: The third of them said: O Allah, you know that I took a hireling for a faraq of rice. When the evening came, I presented to him his due (i.e. his wages). But he refused to take it and went away. I then cultivated it until I amassed cows and their herdsmen for him. He then met me and said: Give me my dues. I said (to him): Go to those cows and their herdsmen and take them all. He went and drove them away}}
\hadithdefcmd{abudawud}{3388}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا يَحْيَى، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي عُبَيْدَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ اشْتَرَكْتُ أَنَا وَعَمَّارٌ، وَسَعْدٌ، فِيمَا نُصِيبُ يَوْمَ بَدْرٍ قَالَ فَجَاءَ سَعْدٌ بِأَسِيرَيْنِ وَلَمْ أَجِئْ أَنَا وَعَمَّارٌ بِشَىْءٍ ‏.‏\hadithno{3388}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Mas'ud: I Ammar, and Sa'd became partners in what we would receive on the day of Badr. Sa'd then brought two prisoners, but I and Ammar did not bring anything}}
\hadithdefcmd{abudawud}{3389}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ دِينَارٍ، قَالَ سَمِعْتُ ابْنَ عُمَرَ، يَقُولُ مَا كُنَّا نَرَى بِالْمُزَارَعَةِ بَأْسًا حَتَّى سَمِعْتُ رَافِعَ بْنَ خَدِيجٍ يَقُولُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْهَا ‏.‏ فَذَكَرْتُهُ لِطَاوُسٍ فَقَالَ قَالَ لِي ابْنُ عَبَّاسٍ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمْ يَنْهَ عَنْهَا وَلَكِنْ قَالَ ‏ "‏ لأَنْ يَمْنَحَ أَحَدُكُمْ أَرْضَهُ خَيْرٌ مِنْ أَنْ يَأْخُذَ عَلَيْهَا خَرَاجًا مَعْلُومًا ‏"‏ ‏.‏\hadithno{3389}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1547)}\hadithtrans{Amr ibn Dinar said:I heard Ibn Umar say: We did not see any harm in sharecropping till I heard Rafi' ibn Khadij say: The Messenger of Allah (ﷺ) has forbidden it. So I mentioned it to Tawus. He said: Ibn Abbas told me that the Messenger of Allah (ﷺ) had not forbidden it, but said: It is better for one of you to lend to his brother than to take a prescribed sum from him}}
\hadithdefcmd{abudawud}{3390}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ عُلَيَّةَ، ح وَحَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا بِشْرٌ، - الْمَعْنَى - عَنْ عَبْدِ الرَّحْمَنِ بْنِ إِسْحَاقَ، عَنْ أَبِي عُبَيْدَةَ بْنِ مُحَمَّدِ بْنِ عَمَّارٍ، عَنِ الْوَلِيدِ بْنِ أَبِي الْوَلِيدِ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، قَالَ قَالَ زَيْدُ بْنُ ثَابِتٍ يَغْفِرُ اللَّهُ لِرَافِعِ بْنِ خَدِيجٍ أَنَا وَاللَّهِ، أَعْلَمُ بِالْحَدِيثِ مِنْهُ إِنَّمَا أَتَاهُ رَجُلاَنِ - قَالَ مُسَدَّدٌ مِنَ الأَنْصَارِ ثُمَّ اتَّفَقَا - قَدِ اقْتَتَلاَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنْ كَانَ هَذَا شَأْنَكُمْ فَلاَ تُكْرُوا الْمَزَارِعَ ‏"‏ ‏.‏ زَادَ مُسَدَّدٌ فَسَمِعَ قَوْلَهُ ‏"‏ لاَ تُكْرُوا الْمَزَارِعَ ‏"‏ ‏.‏\hadithno{3390}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Urwah b. al-Zubair: That Zayd ibn Thabit said: May Allah forgive Rafi' ibn Khadij. I swear by Allah, I have more knowledge of Hadith than him. Two persons of the Ansar (according to the version of Musaddad) came to him who were disputing with each other. The Messenger of Allah (ﷺ) said: If this is your position, then do not lease the agricultural land. The version of Musaddad has: So he (Rafi' ibn Khadij) heard his statement: Do not lease agricultural lands}}
\hadithdefcmd{abudawud}{3391}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ مُحَمَّدِ بْنِ عِكْرِمَةَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَبِيبَةَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ سَعْدٍ، قَالَ كُنَّا نُكْرِي الأَرْضَ بِمَا عَلَى السَّوَاقِي مِنَ الزَّرْعِ وَمَا سَعِدَ بِالْمَاءِ مِنْهَا فَنَهَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ وَأَمَرَنَا أَنْ نُكْرِيَهَا بِذَهَبٍ أَوْ فِضَّةٍ ‏.‏\hadithno{3391}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Sa'd: We used to lease land for what grew by the streamlets and for what was watered from them. The Messenger of Allah (ﷺ) forbade us to do that, and commanded us to lease if for gold or silver}}
\hadithdefcmd{abudawud}{3392}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى الرَّازِيُّ، أَخْبَرَنَا عِيسَى، حَدَّثَنَا الأَوْزَاعِيُّ، ح وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، كِلاَهُمَا عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، - وَاللَّفْظُ لِلأَوْزَاعِيِّ - حَدَّثَنِي حَنْظَلَةُ بْنُ قَيْسٍ الأَنْصَارِيُّ، قَالَ سَأَلْتُ رَافِعَ بْنَ خَدِيجٍ عَنْ كِرَاءِ الأَرْضِ، بِالذَّهَبِ وَالْوَرِقِ فَقَالَ لاَ بَأْسَ بِهَا إِنَّمَا كَانَ النَّاسُ يُؤَاجِرُونَ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم بِمَا عَلَى الْمَاذِيَانَاتِ وَأَقْبَالِ الْجَدَاوِلِ وَأَشْيَاءَ مِنَ الزَّرْعِ فَيَهْلِكُ هَذَا وَيَسْلَمُ هَذَا وَيَسْلَمُ هَذَا وَيَهْلِكُ هَذَا وَلَمْ يَكُنْ لِلنَّاسِ كِرَاءٌ إِلاَّ هَذَا فَلِذَلِكَ زَجَرَ عَنْهُ فَأَمَّا شَىْءٌ مَضْمُونٌ مَعْلُومٌ فَلاَ بَأْسَ بِهِ ‏.‏ وَحَدِيثُ إِبْرَاهِيمَ أَتَمُّ وَقَالَ قُتَيْبَةُ عَنْ حَنْظَلَةَ عَنْ رَافِعٍ ‏.‏ قَالَ أَبُو دَاوُدَ رِوَايَةُ يَحْيَى بْنِ سَعِيدٍ عَنْ حَنْظَلَةَ نَحْوَهُ ‏.‏\hadithno{3392}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2346، 2347) Sahih Muslim (1547 After 1548)}\hadithtrans{Narrated Hanzlah b. Qais al-Ansari: I asked Rafi' b. Khadij about the lease of land for gold and silver (i.e. for dinars and dirhams). There is no harm in it, for the people used to let out land in the time of the Messenger of Allah (ﷺ) for what grew by the current of water and at the banks of streamlets and at the places of cultivation. So sometimes this (portion) perished and that (portion) was saved, and sometimes this remained intact and that perished. There was no (form of) lease among the people except this. Therefore, he forbade it. But if there is something which is secure and known, then there is no harm in it. The tradition of Ibrahim is more perfect. Qutaibah said: "from Hanzalah on the authority of Rafi' ". Abu Dawud said: A similar tradition has been transmitted by Yahya b. Sa'id from Hanzalah}}
\hadithdefcmd{abudawud}{3393}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكٍ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ حَنْظَلَةَ بْنِ قَيْسٍ، أَنَّهُ سَأَلَ رَافِعَ بْنَ خَدِيجٍ عَنْ كِرَاءِ الأَرْضِ، فَقَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ كِرَاءِ الأَرْضِ فَقُلْتُ أَبِالذَّهَبِ وَالْوَرِقِ فَقَالَ أَمَّا بِالذَّهَبِ وَالْوَرِقِ فَلاَ بَأْسَ بِهِ ‏.‏\hadithno{3393}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1547)}\hadithtrans{Hanzalah ibn Qays said that he asked Rafi' ibn Khadij about the lease of land. He replied:The Messenger of Allah (ﷺ) forbade the leasing of land. I asked: (Did he forbid) for gold and silver (i.e. dinars and dirhams)? He replied: If it is against gold and silver, then there is no harm in it}}
\hadithdefcmd{abudawud}{3394}{حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، حَدَّثَنِي أَبِي، عَنْ جَدِّي اللَّيْثِ، حَدَّثَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ ابْنَ عُمَرَ، كَانَ يُكْرِي أَرْضَهُ حَتَّى بَلَغَهُ أَنَّ رَافِعَ بْنَ خَدِيجٍ الأَنْصَارِيَّ حَدَّثَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَنْهَى عَنْ كِرَاءِ الأَرْضِ فَلَقِيَهُ عَبْدُ اللَّهِ فَقَالَ يَا ابْنَ خَدِيجٍ مَاذَا تُحَدِّثُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي كِرَاءِ الأَرْضِ قَالَ رَافِعٌ لِعَبْدِ اللَّهِ بْنِ عُمَرَ سَمِعْتُ عَمَّىَّ وَكَانَا قَدْ شَهِدَا بَدْرًا يُحَدِّثَانِ أَهْلَ الدَّارِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ كِرَاءِ الأَرْضِ ‏.‏ قَالَ عَبْدُ اللَّهِ وَاللَّهِ لَقَدْ كُنْتُ أَعْلَمُ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّ الأَرْضَ تُكْرَى ‏.‏ ثُمَّ خَشِيَ عَبْدُ اللَّهِ أَنْ يَكُونَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَحْدَثَ فِي ذَلِكَ شَيْئًا لَمْ يَكُنْ عَلِمَهُ فَتَرَكَ كِرَاءَ الأَرْضِ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ أَيُّوبُ وَعُبَيْدُ اللَّهِ وَكَثِيرُ بْنُ فَرْقَدٍ وَمَالِكٌ عَنْ نَافِعٍ عَنْ رَافِعٍ عَنِ النَّبِيِّ صلى الله عليه وسلم وَرَوَاهُ الأَوْزَاعِيُّ عَنْ حَفْصِ بْنِ عِنَانٍ عَنْ نَافِعٍ عَنْ رَافِعٍ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَكَذَلِكَ رَوَاهُ زَيْدُ بْنُ أَبِي أُنَيْسَةَ عَنِ الْحَكَمِ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ أَنَّهُ أَتَى رَافِعًا فَقَالَ سَمِعْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ نَعَمْ ‏.‏ وَكَذَا قَالَ عِكْرِمَةُ بْنُ عَمَّارٍ عَنْ أَبِي النَّجَاشِيِّ عَنْ رَافِعِ بْنِ خَدِيجٍ قَالَ سَمِعْتُ النَّبِيَّ عَلَيْهِ السَّلاَمُ ‏.‏ وَرَوَاهُ الأَوْزَاعِيُّ عَنْ أَبِي النَّجَاشِيِّ عَنْ رَافِعِ بْنِ خَدِيجٍ عَنْ عَمِّهِ ظُهَيْرِ بْنِ رَافِعٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو دَاوُدَ أَبُو النَّجَاشِيِّ عَطَاءُ بْنُ صُهَيْبٍ ‏.‏\hadithno{3394}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2345) Sahih Muslim (1547)}\hadithtrans{Narrated Salim bin 'Abdullah b. 'Umar: Ibn 'Umar used to let out his land till it reached him that Rafi' b. Khadij al-Ansari narrated that the Messenger of Allah (ﷺ) forbade let out land. So 'Abd Allah (b. 'Umar) said: Ibn Khadij, what do you narrate from the Messenger of Allah (ﷺ) about leasing the land? Rafi' replied to 'Abd Allah b. 'Umar: I heard both of my uncles were present in the battle of Badr say, and they narrated it to the members of the family, that the Messenger of Allah (ﷺ) forbade leasing land. 'Abd Allah said: I swear by Allah, I knew that land was leased in the time of the Messenger of Allah (ﷺ). 'Abd Allah then feared that the Messenger of Allah (ﷺ) might have created something new in that matter, so he gave up leasing land. Abu Dawud said: This tradition has also been transmitted by Ayyub, 'Ubaid Allah, Kathir b. Farqad, Malik from Nafi' on the authority of Rafi' from the Prophet (ﷺ). It has also been transmitted by al-Auzai' from Hafs b. 'Inan al-Hanafi from Nafi' from Rafi' who said: I heard the Messenger of Allah (ﷺ) say: Similarly, it has been transmitted by Zaid b. Abi Unaisah from al-Hakkam from Nafi' from Ibn 'Umar that he went to Rafi' and asked: Have you heard the Messenger of Allah (ﷺ) say? He replied: Yes. Similarly, it has also been transmitted by 'Ikrimah b. 'Ammar from Abu al-Najashi, from Rafi' b. Khadij who said: I heard the Prophet (ﷺ) say. It has also been transmitted by al-Auza'i from Abu al-Najashi from Rafi' b. Khadij from his uncle Zuhair b. Rafi' from the Prophet (ﷺ). Abu Dawud said: The name of Abu al-Najashi is 'Ata b. Suhaib}}
\hadithdefcmd{abudawud}{3395}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ بْنِ مَيْسَرَةَ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا سَعِيدٌ، عَنْ يَعْلَى بْنِ حَكِيمٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، أَنَّ رَافِعَ بْنَ خَدِيجٍ، قَالَ كُنَّا نُخَابِرُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ أَنَّ بَعْضَ عُمُومَتِهِ أَتَاهُ فَقَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ أَمْرٍ كَانَ لَنَا نَافِعًا وَطَوَاعِيَةُ اللَّهِ وَرَسُولِهِ أَنْفَعُ لَنَا وَأَنْفَعُ ‏.‏ قَالَ قُلْنَا وَمَا ذَاكَ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ كَانَتْ لَهُ أَرْضٌ فَلْيَزْرَعْهَا أَوْ فَلْيُزْرِعْهَا أَخَاهُ وَلاَ يُكَارِيهَا بِثُلُثٍ وَلاَ بِرُبُعٍ وَلاَ بِطَعَامٍ مُسَمًّى ‏"‏ ‏.‏\hadithno{3395}\hadithgrade{Al-Albani: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1548)}\hadithtrans{Narrated Rafi' b. Khadij:We used to employ people to till land for a share of it produce. He then maintained that, one of his uncles came to him and said: The Messenger of Allah (ﷺ) forbade us from a work which beneficial to us. But obedience to Allah and His Apostle (ﷺ) is more beneficial to us. We asked : What is that ? He said: The Messenger of Allah (ﷺ) said: If anyone has land, he should cultivate it, or lend it to his brother for cultivation. He should not rent it for a third or a quarter (of the produce) or for specified among of produce}}
\hadithdefcmd{abudawud}{3396}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، قَالَ كَتَبَ إِلَىَّ يَعْلَى بْنُ حَكِيمٍ أَنِّي سَمِعْتُ سُلَيْمَانَ بْنَ يَسَارٍ، بِمَعْنَى إِسْنَادِ عُبَيْدِ اللَّهِ وَحَدِيثِهِ ‏.‏\hadithno{3396}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1548)}\hadithtrans{Ayyub said:Ya'la b. Hakim wrote to me: I heard Sulaiman b. Yasar narrating the tradition to the same effect as narrated by 'Ubaid Allah and through the same chain}}
\hadithdefcmd{abudawud}{3397}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا عُمَرُ بْنُ ذَرٍّ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ رَافِعِ بْنِ خَدِيجٍ، عَنْ أَبِيهِ، قَالَ جَاءَنَا أَبُو رَافِعٍ مِنْ عِنْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ نَهَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ أَمْرٍ كَانَ يَرْفَقُ بِنَا وَطَاعَةُ اللَّهِ وَطَاعَةُ رَسُولِهِ أَرْفَقُ بِنَا نَهَانَا أَنْ يَزْرَعَ أَحَدُنَا إِلاَّ أَرْضًا يَمْلِكُ رَقَبَتَهَا أَوْ مَنِيحَةً يَمْنَحُهَا رَجُلٌ ‏.‏\hadithno{3397}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Lighairihi; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Rafi' ibn Khadij: AbuRafi' came to us from the Messenger of Allah (ﷺ) said: The Messenger of Allah (ﷺ) forbade us from a work which benefited us; but obedience to Allah and His Apostle (ﷺ) is more beneficial to us. He forbade that one of us cultivates land except the one which he owns or the land which a man lends him (to cultivate)}}
\hadithdefcmd{abudawud}{3398}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، أَنَّ أُسَيْدَ بْنَ ظُهَيْرٍ، قَالَ جَاءَنَا رَافِعُ بْنُ خَدِيجٍ فَقَالَ إِنَّ رَسُولَ اللَّهِ يَنْهَاكُمْ عَنْ أَمْرٍ، كَانَ لَكُمْ نَافِعًا وَطَاعَةُ اللَّهِ وَطَاعَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنْفَعُ لَكُمْ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم يَنْهَاكُمْ عَنِ الْحَقْلِ وَقَالَ ‏ "‏ مَنِ اسْتَغْنَى عَنْ أَرْضِهِ فَلْيَمْنَحْهَا أَخَاهُ أَوْ لِيَدَعْ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَهَكَذَا رَوَاهُ شُعْبَةُ وَمُفَضَّلُ بْنُ مُهَلْهَلٍ عَنْ مَنْصُورٍ ‏.‏ قَالَ شُعْبَةُ أُسَيْدُ ابْنُ أَخِي رَافِعِ بْنِ خَدِيجٍ ‏.‏\hadithno{3398}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Usaid b. Zuhair: Rafi' b. Khadij came to us and said: The Messenger of Allah (ﷺ) forbids you from a work which is beneficial to you ; and obedience to Allah and His Prophet (ﷺ) is more beneficial to you. The Messenger of Allah (ﷺ) forbids you from renting land for share of its produce and he said: If anyone if not in need of his land he should lend it to his brother or leave it. Abu Dawud said: Shu'bah and Mufaddal b. Muhalhal have narrated it from Mansur in similar way. Shu'bah said (in his version): Usaid, nephew of Rafi' b, Khadij}}
\hadithdefcmd{abudawud}{3399}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى، حَدَّثَنَا أَبُو جَعْفَرٍ الْخَطْمِيُّ، قَالَ بَعَثَنِي عَمِّي أَنَا وَغُلاَمًا، لَهُ إِلَى سَعِيدِ بْنِ الْمُسَيَّبِ قَالَ فَقُلْنَا لَهُ شَىْءٌ بَلَغَنَا عَنْكَ فِي الْمُزَارَعَةِ ‏.‏ قَالَ كَانَ ابْنُ عُمَرَ لاَ يَرَى بِهَا بَأْسًا حَتَّى بَلَغَهُ عَنْ رَافِعِ بْنِ خَدِيجٍ حَدِيثٌ فَأَتَاهُ فَأَخْبَرَهُ رَافِعٌ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَتَى بَنِي حَارِثَةَ فَرَأَى زَرْعًا فِي أَرْضِ ظُهَيْرٍ فَقَالَ ‏"‏ مَا أَحْسَنَ زَرْعَ ظُهَيْرٍ ‏"‏ ‏.‏ قَالُوا لَيْسَ لِظُهَيْرٍ ‏.‏ قَالَ ‏"‏ أَلَيْسَ أَرْضُ ظُهَيْرٍ ‏"‏ ‏.‏ قَالُوا بَلَى وَلَكِنَّهُ زَرْعُ فُلاَنٍ ‏.‏ قَالَ ‏"‏ فَخُذُوا زَرْعَكُمْ وَرُدُّوا عَلَيْهِ النَّفَقَةَ ‏"‏ ‏.‏ قَالَ رَافِعٌ فَأَخَذْنَا زَرْعَنَا وَرَدَدْنَا إِلَيْهِ النَّفَقَةَ ‏.‏ قَالَ سَعِيدٌ أَفْقِرْ أَخَاكَ أَوْ أَكْرِهِ بِالدَّرَاهِمِ ‏.‏\hadithno{3399}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{AbuJa'far al-Khatmi said:My uncle sent me and his slave to Sa'id ibn al-Musayyab. We said to him, there is something which has reached us about sharecropping. He replied: Ibn Umar did not see any harm in it until a tradition reached him from Rafi' ibn Khadij. He then came to him and Rafi' told him that the Messenger of Allah (ﷺ) came to Banu Harithah and saw crop in the land of Zuhayr. He said: What an excellent crop of Zuhayr is! They said: It does not belong to Zuhayr. He asked: Is this not the land of Zuhayr? They said: Yes, but the crop belongs to so-and-so. He said: Take your crop and give him the wages. Rafi' said: We took our crop and gave him the wages. Sa'id (ibn al-Musayyab) said: Lend your brother or employ him for dirhams}}
\hadithdefcmd{abudawud}{3400}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، حَدَّثَنَا طَارِقُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ رَافِعِ بْنِ خَدِيجٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْمُحَاقَلَةِ وَالْمُزَابَنَةِ وَقَالَ ‏ "‏ إِنَّمَا يَزْرَعُ ثَلاَثَةٌ رَجُلٌ لَهُ أَرْضٌ فَهُوَ يَزْرَعُهَا وَرَجُلٌ مُنِحَ أَرْضًا فَهُوَ يَزْرَعُ مَا مُنِحَ وَرَجُلٌ اسْتَكْرَى أَرْضًا بِذَهَبٍ أَوْ فِضَّةٍ ‏"‏ ‏.‏\hadithno{3400}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Rafi' ibn Khadij: The Messenger of Allah (ﷺ) forbade muhaqalah and muzabanah. Those who cultivate land are three: a man who has (his own) land and he tills it: a man who has been lent land and he tills the one lent to him; a man who employs another man to till land against gold (dinars) or silver (dirhams)}}
\hadithdefcmd{abudawud}{3401}{قَالَ أَبُو دَاوُدَ قَرَأْتُ عَلَى سَعِيدِ بْنِ يَعْقُوبَ الطَّالْقَانِيِّ قُلْتُ لَهُ حَدَّثَكُمُ ابْنُ الْمُبَارَكِ، عَنْ سَعِيدٍ أَبِي شُجَاعٍ، حَدَّثَنِي عُثْمَانُ بْنُ سَهْلِ بْنِ رَافِعِ بْنِ خَدِيجٍ، قَالَ إِنِّي لَيَتِيمٌ فِي حِجْرِ رَافِعِ بْنِ خَدِيجٍ وَحَجَجْتُ مَعَهُ فَجَاءَهُ أَخِي عِمْرَانُ بْنُ سَهْلٍ فَقَالَ أَكْرَيْنَا أَرْضَنَا فُلاَنَةَ بِمِائَتَىْ دِرْهَمٍ فَقَالَ دَعْهُ فَإِنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ كِرَاءِ الأَرْضِ ‏.‏\hadithno{3401}\hadithgrade{Al-Albani: Shadh; Muhammad Muhyi Al-Din Abdul Hamid: Shadh; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Dawud said:I read out (this tradition) to Sa'id b. Ya'qub al-Taliqini, and I said to him: Ibn al-Mubarak transmitted (this tradition) to you from Sa'id Abi Shuja' who said: 'Uthman b. Sahl b. Rafi' b. Khadij narrated it to me saying: I was an orphan being nourished under the guardianship of Rafi' b. Khadij and I performed Hajj with him. My brother 'Imran b. Sahl then came to me and said: We rented out land to so-and-so for two hundred dirhams. He said: Leave it, for the Prophet (ﷺ) forbade renting land}}
\hadithdefcmd{abudawud}{3402}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا الْفَضْلُ بْنُ دُكَيْنٍ، حَدَّثَنَا بُكَيْرٌ، - يَعْنِي ابْنَ عَامِرٍ - عَنِ ابْنِ أَبِي نُعْمٍ، حَدَّثَنِي رَافِعُ بْنُ خَدِيجٍ، أَنَّهُ زَرَعَ أَرْضًا فَمَرَّ بِهِ النَّبِيُّ صلى الله عليه وسلم وَهُوَ يَسْقِيهَا فَسَأَلَهُ ‏"‏ لِمَنِ الزَّرْعُ وَلِمَنِ الأَرْضُ ‏"‏ ‏.‏ فَقَالَ زَرْعِي بِبَذْرِي وَعَمَلِي لِيَ الشَّطْرُ وَلِبَنِي فُلاَنٍ الشَّطْرُ ‏.‏ فَقَالَ ‏"‏ أَرْبَيْتُمَا فَرُدَّ الأَرْضَ عَلَى أَهْلِهَا وَخُذْ نَفَقَتَكَ ‏"‏ ‏.‏\hadithno{3402}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Rafi' ibn Khadij: Rafi' had cultivated a land. The Prophet (ﷺ) passed him when he was watering it. So he asked him: To whom does the crop belong, and to whom does the land belong? He replied: The crop is mine for my seed and labour. The half (of the crop) is mine and the half for so-and-so. He said: You conducted usurious transaction. Return the land to its owner and take your wages and cost}}
\hadithdefcmd{abudawud}{3403}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا شَرِيكٌ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَطَاءٍ، عَنْ رَافِعِ بْنِ خَدِيجٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ زَرَعَ فِي أَرْضِ قَوْمٍ بِغَيْرِ إِذْنِهِمْ فَلَيْسَ لَهُ مِنَ الزَّرْعِ شَىْءٌ وَلَهُ نَفَقَتُهُ ‏"‏ ‏.‏\hadithno{3403}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Rafi' ibn Khadij: The Prophet (ﷺ) said: If anyone sows in other people's land without their permission, he has no right to any of the crop, but he may have what it cost him}}
\hadithdefcmd{abudawud}{3404}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا إِسْمَاعِيلُ، ح وَحَدَّثَنَا مُسَدَّدٌ، أَنَّ حَمَّادًا، وَعَبْدَ الْوَارِثِ، حَدَّثَاهُمْ كُلُّهُمْ، عَنْ أَيُّوبَ، عَنْ أَبِي الزُّبَيْرِ، - قَالَ عَنْ حَمَّادٍ، وَسَعِيدِ بْنِ مِينَاءَ، ثُمَّ اتَّفَقُوا - عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْمُحَاقَلَةِ وَالْمُزَابَنَةِ وَالْمُخَابَرَةِ وَالْمُعَاوَمَةِ - قَالَ عَنْ حَمَّادٍ وَقَالَ أَحَدُهُمَا وَالْمُعَاوَمَةِ وَقَالَ الآخَرُ بَيْعِ السِّنِينَ ثُمَّ اتَّفَقُوا - وَعَنِ الثُّنْيَا وَرَخَّصَ فِي الْعَرَايَا ‏.‏\hadithno{3404}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1536 After  1543)}\hadithtrans{Narrated Jabir b. 'Abd Allah :The Messenger of Allah (ﷺ) forbade muhaqalah, muzabanah, mukhabarah, and mu'awanah. One of the two narrators from Hammad said the word mu'awamah, and other said: "selling many years ahead". The agreed version then goes: and thunya, but gave license for 'araya}}
\hadithdefcmd{abudawud}{3405}{حَدَّثَنَا أَبُو حَفْصٍ، عُمَرُ بْنُ يَزِيدَ السَّيَّارِيُّ حَدَّثَنَا عَبَّادُ بْنُ الْعَوَّامِ، عَنْ سُفْيَانَ بْنِ حُسَيْنٍ، عَنْ يُونُسَ بْنِ عُبَيْدٍ، عَنْ عَطَاءٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْمُزَابَنَةِ وَالْمُحَاقَلَةِ وَعَنِ الثُّنْيَا إِلاَّ أَنْ يُعْلَمَ ‏.‏\hadithno{3405}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Jabir b. 'Abd Allah :The Messenger of Allah (ﷺ) forbade muzabanah, muhaqalah and thunya except it is known}}
\hadithdefcmd{abudawud}{3406}{حَدَّثَنَا يَحْيَى بْنُ مَعِينٍ، حَدَّثَنَا ابْنُ رَجَاءٍ، - يَعْنِي الْمَكِّيَّ - قَالَ ابْنُ خُثَيْمٍ حَدَّثَنِي عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ لَمْ يَذَرِ الْمُخَابَرَةَ فَلْيَأْذَنْ بِحَرْبٍ مِنَ اللَّهِ وَرَسُولِهِ ‏"‏ ‏.‏\hadithno{3406}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir b. 'Abd Allah :I heard the Messenger of Allah (ﷺ) say: If any of you does not leave mukhabarah, he should take notice of war from Allah and His Apostle (ﷺ)}}
\hadithdefcmd{abudawud}{3407}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عُمَرُ بْنُ أَيُّوبَ، عَنْ جَعْفَرِ بْنِ بُرْقَانَ، عَنْ ثَابِتِ بْنِ الْحَجَّاجِ، عَنْ زَيْدِ بْنِ ثَابِتٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْمُخَابَرَةِ ‏.‏ قُلْتُ وَمَا الْمُخَابَرَةُ قَالَ أَنْ تَأْخُذَ الأَرْضَ بِنِصْفٍ أَوْ ثُلُثٍ أَوْ رُبُعٍ ‏.‏\hadithno{3407}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Zaid b. Thabit:The Messenger of Allah (ﷺ) forbade mukhabarah. I asked: What is mukhabarah ? He replied: That you have the land (for cultivation) for half, a third, or a quarter (of the produce)}}
\hadithdefcmd{abudawud}{3408}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم عَامَلَ أَهْلَ خَيْبَرَ بِشَطْرِ مَا يَخْرُجُ مِنْ ثَمَرٍ أَوْ زَرْعٍ ‏.‏\hadithno{3408}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2329) Sahih Muslim (1551)}\hadithtrans{Narrated Ibn 'Umar:The Messenger of Allah (ﷺ) made an agreement with the people of Khaibar to work and cultivate in return for half of the fruits or produce}}
\hadithdefcmd{abudawud}{3409}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنِ اللَّيْثِ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، - يَعْنِي ابْنَ غَنَجٍ - عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم دَفَعَ إِلَى يَهُودِ خَيْبَرَ نَخْلَ خَيْبَرَ وَأَرْضَهَا عَلَى أَنْ يَعْتَمِلُوهَا مِنْ أَمْوَالِهِمْ وَأَنَّ لِرَسُولِ اللَّهِ صلى الله عليه وسلم شَطْرَ ثَمَرَتِهَا ‏.‏\hadithno{3409}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1551)}\hadithtrans{Narrated Ibn 'Umar:The Prophet (ﷺ) handed over the Jews of Khaibar the palm trees and the land of Khaibar on condition that they should employ what belonged to them in working on them, and that he should have half of the fruits}}
\hadithdefcmd{abudawud}{3410}{حَدَّثَنَا أَيُّوبُ بْنُ مُحَمَّدٍ الرَّقِّيُّ، حَدَّثَنَا عُمَرُ بْنُ أَيُّوبَ، حَدَّثَنَا جَعْفَرُ بْنُ بُرْقَانَ، عَنْ مَيْمُونِ بْنِ مِهْرَانَ، عَنْ مِقْسَمٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ افْتَتَحَ رَسُولُ اللَّهِ صلى الله عليه وسلم خَيْبَرَ وَاشْتَرَطَ أَنَّ لَهُ الأَرْضَ وَكُلَّ صَفْرَاءَ وَبَيْضَاءَ ‏.‏ قَالَ أَهْلُ خَيْبَرَ نَحْنُ أَعْلَمُ بِالأَرْضِ مِنْكُمْ فَأَعْطِنَاهَا عَلَى أَنَّ لَكُمْ نِصْفَ الثَّمَرَةِ وَلَنَا نِصْفٌ ‏.‏ فَزَعَمَ أَنَّهُ أَعْطَاهُمْ عَلَى ذَلِكَ فَلَمَّا كَانَ حِينَ يُصْرَمُ النَّخْلُ بَعَثَ إِلَيْهِمْ عَبْدَ اللَّهِ بْنَ رَوَاحَةَ فَحَزَرَ عَلَيْهِمُ النَّخْلَ وَهُوَ الَّذِي يُسَمِّيهِ أَهْلُ الْمَدِينَةِ الْخَرْصَ فَقَالَ فِي ذِهْ كَذَا وَكَذَا قَالُوا أَكْثَرْتَ عَلَيْنَا يَا ابْنَ رَوَاحَةَ ‏.‏ فَقَالَ فَأَنَا أَلِي حَزْرَ النَّخْلِ وَأُعْطِيكُمْ نِصْفَ الَّذِي قُلْتُ ‏.‏ قَالُوا هَذَا الْحَقُّ وَبِهِ تَقُومُ السَّمَاءُ وَالأَرْضُ قَدْ رَضِينَا أَنْ نَأْخُذَهُ بِالَّذِي قُلْتَ ‏.‏\hadithno{3410}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ibn 'Abbas:The Messenger of Allah (ﷺ) conquered Khaibar, and stipulated that all the land, gold and silver would belong to him. The people of Khaibar said: we know the land more than you ; so give it to us on condition that you should have half of the produce and we would have the half. He then gave it to them on that condition. When the time of picking the fruits of the palm-trees came, he sent 'Abd Allah b. Rawahah to them, and he assessed the among of the fruits of the palm-trees. This is what the people of Medina call khars (assessment). He used to say: In these palm-trees there is such-and-such amount (of produce). They would say: You assessed more to us, Ibn Rawahah (than the real amount). He would say: I first take the responsibility of assessing the fruits of the palm-trees and give you half of (the amount) I said. They would say: This is true, and on this (equity) stand the heavens and the earth. We agreed that we should take (the amount which) you said}}
\hadithdefcmd{abudawud}{3411}{حَدَّثَنَا مُحَمَّدُ بْنُ سَهْلٍ الرَّمْلِيُّ، حَدَّثَنَا زَيْدُ بْنُ أَبِي الزَّرْقَاءِ، عَنْ جَعْفَرِ بْنِ بُرْقَانَ، بِإِسْنَادِهِ وَمَعْنَاهُ قَالَ فَحَزَرَ وَقَالَ عِنْدَ قَوْلِهِ وَكُلَّ صَفْرَاءَ وَبَيْضَاءَ يَعْنِي الذَّهَبَ وَالْفِضَّةَ لَهُ ‏.‏\hadithno{3411}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{The tradition mentioned above has also been narrated by Ja'far b. Burqan through his chain and to the same effect. This version has:He said: He assessed, and after the words of kull safara' wa baida', he said: that is, gold and silver will belong to him}}
\hadithdefcmd{abudawud}{3412}{حَدَّثَنَا مُحَمَّدُ بْنُ سُلَيْمَانَ الأَنْبَارِيُّ، حَدَّثَنَا كَثِيرٌ، - يَعْنِي ابْنَ هِشَامٍ - عَنْ جَعْفَرِ بْنِ بُرْقَانَ، حَدَّثَنَا مَيْمُونٌ، عَنْ مِقْسَمٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم حِينَ افْتَتَحَ خَيْبَرَ فَذَكَرَ نَحْوَ حَدِيثِ زَيْدٍ قَالَ فَحَزَرَ النَّخْلَ وَقَالَ فَأَنَا أَلِي جُذَاذَ النَّخْلِ وَأُعْطِيكُمْ نِصْفَ الَّذِي قُلْتُ ‏.‏\hadithno{3412}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Miqsam:When the Prophet (ﷺ) conquered Khaibar. He then narrated it like the tradition of Zaid (b. Abu al-Zarqa'). This version has: He then assessed the produce of the palm-trees and said: I take the job of picking the fruit myself, and I shall give you half of (the amount) I said}}
\hadithdefcmd{abudawud}{3413}{حَدَّثَنَا يَحْيَى بْنُ مَعِينٍ، حَدَّثَنَا حَجَّاجٌ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أُخْبِرْتُ عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يَبْعَثُ عَبْدَ اللَّهِ بْنَ رَوَاحَةَ فَيَخْرُصُ النَّخْلَ حِينَ يَطِيبُ قَبْلَ أَنْ يُؤْكَلَ مِنْهُ ثُمَّ يُخَيِّرُ يَهُودَ يَأْخُذُونَهُ بِذَلِكَ الْخَرْصِ أَوْ يَدْفَعُونَهُ إِلَيْهِمْ بِذَلِكَ الْخَرْصِ لِكَىْ تُحْصَى الزَّكَاةُ قَبْلَ أَنْ تُؤْكَلَ الثِّمَارُ وَتُفَرَّقَ ‏.‏\hadithno{3413}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Prophet (ﷺ) used to send Abdullah ibn Rawahah (to Khaybar), and he would assess the amount of dates when they began to ripen before they were eaten (by the Jews). He would then give choice to the Jews that they have them (on their possession) by that assessment or could assign to them (Muslims) by that assignment, so that the (amount of) zakat could be calculated before the fruit became eatable and distributed (among the people)}}
\hadithdefcmd{abudawud}{3414}{حَدَّثَنَا ابْنُ أَبِي خَلَفٍ، حَدَّثَنَا مُحَمَّدُ بْنُ سَابِقٍ، عَنْ إِبْرَاهِيمَ بْنِ طَهْمَانَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّهُ قَالَ أَفَاءَ اللَّهُ عَلَى رَسُولِهِ خَيْبَرَ فَأَقَرَّهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم كَمَا كَانُوا وَجَعَلَهَا بَيْنَهُ وَبَيْنَهُمْ فَبَعَثَ عَبْدَ اللَّهِ بْنَ رَوَاحَةَ فَخَرَصَهَا عَلَيْهِمْ ‏.‏\hadithno{3414}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir ibn Abdullah: When Allah bestowed Khaybar on His Prophet (ﷺ) as fay' (as a result of conquest without fighting), the Messenger of Allah (ﷺ) allowed (them) to remain there as they were before, and apportioned it between him and them. He then sent Abdullah ibn Rawahah who assessed (the amount of dates) upon them}}
\hadithdefcmd{abudawud}{3415}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، وَمُحَمَّدُ بْنُ بَكْرٍ، قَالاَ حَدَّثَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ خَرَصَهَا ابْنُ رَوَاحَةَ أَرْبَعِينَ أَلْفَ وَسْقٍ وَزَعَمَ أَنَّ الْيَهُودَ لَمَّا خَيَّرَهُمُ ابْنُ رَوَاحَةَ أَخَذُوا الثَّمَرَ وَعَلَيْهِمْ عِشْرُونَ أَلْفَ وَسْقٍ ‏.‏\hadithno{3415}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Jabir ibn Abdullah: Ibn Rawahah assessed them (the amount of dates) at forty thousand wasqs, and when Ibn Rawahah gave them option, the Jews took the fruits in their possession and twenty thousand wasqs of dates were due from them}}
